local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local mission_util = include( "sim/missions/mission_util" )
local speechdefs = include( "sim/speechdefs" )
---------------------------------------------------------------------------------------------
-- Local helpers

local function isConsolePred( u )
	return u:getTraits().mainframe_console and not u:getTraits().console_incident
end

local function hijackConsole( script, sim )
	local consoleUnit = simquery.findUnit( sim:getAllUnits(), isConsolePred )
	if consoleUnit == nil then
		log:write( "W93_console_drone_control : no valid console" )
		return
	end

	log:write( "W93_console_drone_control : unit [%d] at <%d, %d>", consoleUnit:getID(), consoleUnit:getLocation() )
	consoleUnit:getTraits().console_incident = true

	local _, triggerData = script:waitFor( mission_util.PC_HIJACKED( consoleUnit:getID() ))
    	local unit = triggerData.sourceUnit

	local targetDrone = nil
	for i, drone in ipairs (sim:getNPC():getUnits()) do
		if drone:getTraits().isDrone then
			targetDrone = drone
			break
		end
	end

	local title = STRINGS.ITEMSEXTEND.INCIDENTS.DRONE_CONTROL_TITLE
	local txt = nil
	local options = nil

	if not targetDrone then
		txt = string.format( STRINGS.ITEMSEXTEND.INCIDENTS.DRONE_CONTROL_DESC2, unit:getName() )
		options = { STRINGS.ITEMSEXTEND.INCIDENTS.DRONE_CONTROL_OPTION3 }
	else
		txt = string.format( STRINGS.ITEMSEXTEND.INCIDENTS.DRONE_CONTROL_DESC1, unit:getName(), targetDrone:getName() )
		options = 
		{ 
			STRINGS.ITEMSEXTEND.INCIDENTS.DRONE_CONTROL_OPTION3,
			STRINGS.ITEMSEXTEND.INCIDENTS.DRONE_CONTROL_OPTION1,
			STRINGS.ITEMSEXTEND.INCIDENTS.DRONE_CONTROL_OPTION2
		}
	end

	local option = mission_util.showDialog( sim, title, txt, options )

	if option == 1 then
		mission_util.showNeutralResult( sim, title, string.format(STRINGS.ITEMSEXTEND.INCIDENTS.DRONE_CONTROL_NEUTRAL, unit:getName() ) )
	elseif option == 2 then
		local currentPlayer = sim:getCurrentPlayer()
		if currentPlayer:getCpus() >= 3 and sim:nextRand(1,100) <= 25 then
			mission_util.showGoodResult( sim, title, string.format(STRINGS.ITEMSEXTEND.INCIDENTS.DRONE_CONTROL_SUCCESS, targetDrone:getName()) )
			targetDrone:setKO( sim, 30 )
		else
			mission_util.showBadResult( sim, title, string.format(STRINGS.ITEMSEXTEND.INCIDENTS.DRONE_CONTROL_FAILURE, targetDrone:getName()) )
			targetDrone:setAlerted(true)
    	        	local x0, y0 = unit:getLocation()
	            	sim:getNPC():spawnInterest(x0, y0, simdefs.SENSE_RADIO, simdefs.REASON_HUNTING, targetDrone)
			sim:dispatchEvent( simdefs.EV_UNIT_ALERTED, { unitID = targetDrone:getID() } )
			targetDrone:getSim():emitSpeech( targetDrone, speechdefs.HUNT_NOISE)
		end
		currentPlayer:addCPUs(-3)
	elseif option == 3 then
		local hasItem = false

		for i, item in pairs( unit:getChildren() ) do 
			if item:hasAbility( "jackin" ) then
				hasItem = true
			end
		end 
	
		if hasItem then
			mission_util.showGoodResult( sim, title, string.format(STRINGS.ITEMSEXTEND.INCIDENTS.DRONE_CONTROL_SUCCESS, targetDrone:getName()) )
			targetDrone:setKO( sim, 30 )
		else
			mission_util.showBadResult( sim, title, string.format(STRINGS.ITEMSEXTEND.INCIDENTS.DRONE_CONTROL_FAILURE, targetDrone:getName()) )
			targetDrone:setAlerted(true)
    	        	local x0, y0 = unit:getLocation()
	            	sim:getNPC():spawnInterest(x0, y0, simdefs.SENSE_RADIO, simdefs.REASON_HUNTING, targetDrone)
			sim:dispatchEvent( simdefs.EV_UNIT_ALERTED, { unitID = targetDrone:getID() } )
			targetDrone:getSim():emitSpeech( targetDrone, speechdefs.HUNT_NOISE)
		end
	end
end

---------------------------------------------------------------------------------------------
-- Begin!

local incident = class()

function incident:init( scriptMgr, sim )
	self.scriptMgr = scriptMgr
	scriptMgr:addHook( STRINGS.ITEMSEXTEND.INCIDENTS.DRONE_CONTROL_TITLE, hijackConsole, false )
end

return incident
