local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local mission_util = include( "sim/missions/mission_util" )

---------------------------------------------------------------------------------------------
-- Local helpers

local function isConsolePred( u )
	return u:getTraits().mainframe_console and not u:getTraits().console_incident
end

local function hijackConsole( script, sim )
	local consoleUnit = simquery.findUnit( sim:getAllUnits(), isConsolePred )
	if consoleUnit == nil then
		log:write( "W93_console_item_order : no valid console" )
		return
	end

	log:write( "W93_console_item_order : unit [%d] at <%d, %d>", consoleUnit:getID(), consoleUnit:getLocation() )
	consoleUnit:getTraits().console_incident = true

	local _, triggerData = script:waitFor( mission_util.PC_HIJACKED( consoleUnit:getID() ))
    	local unit = triggerData.sourceUnit

	local title = STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_TITLE
	local txt = string.format( STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_DESC, unit:getName() )
	local options = 
	{ 
		STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_OPTION1,
		STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_OPTION2,
		STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_OPTION3,
		STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_OPTION4,
	}
	local option = mission_util.showDialog( sim, title, txt, options )

	if option == 1 then
		local currentPlayer = sim:getCurrentPlayer()
		if currentPlayer:getCpus() >= 3 and sim:nextRand(1,100) <= 15 then
			mission_util.showGoodResult( sim, title, STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_SUCCESS )
			local result = sim:nextRand(1,100)
			if result <= 10 then
				mission_util.giftItem( sim, unit, "item_bio_dartgun" )
			elseif result > 10 and result <= 25 then
				mission_util.giftItem( sim, unit, "item_light_pistol_KO" )
			elseif result > 25 and result <= 55 then
				mission_util.giftItem( sim, unit, "item_dartgun" )
			else
				mission_util.giftItem( sim, unit, "item_tazer" )
			end
		else
			mission_util.showBadResult( sim, title, STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_FAILURE )
			sim:trackerAdvance(3)
		end
		currentPlayer:addCPUs(-3)
	elseif option == 2 then
		local currentPlayer = sim:getCurrentPlayer()
		if currentPlayer:getCpus() >= 3 and sim:nextRand(1,100) <= 25 then
			mission_util.showGoodResult( sim, title, STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_SUCCESS )
			local result = sim:nextRand(1,100)
			if result <= 10 then
				mission_util.giftItem( sim, unit, "W93_augment_icebreak" )
			elseif result > 10 and result <= 25 then
				mission_util.giftItem( sim, unit, "W93_augment_dartKO_fabricator" )
			elseif result > 25 and result <= 55 then
				mission_util.giftItem( sim, unit, "W93_augment_hostage_monitor" )
			else
				mission_util.giftItem( sim, unit, "augment_distributed_processing" )
			end
		else
			mission_util.showBadResult( sim, title, STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_FAILURE )
			sim:trackerAdvance(3)
		end
		currentPlayer:addCPUs(-3)
	elseif option == 3 then
		local currentPlayer = sim:getCurrentPlayer()
		if currentPlayer:getCpus() >= 3 and sim:nextRand(1,100) <= 35 then
			mission_util.showGoodResult( sim, title, STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_SUCCESS )
			local result = sim:nextRand(1,100)
			if result <= 10 then
				mission_util.giftItem( sim, unit, "item_icebreaker_2" )
			elseif result > 10 and result <= 25 then
				mission_util.giftItem( sim, unit, "W93_item_drone_toolkit" )
			elseif result > 25 and result <= 55 then
				mission_util.giftItem( sim, unit, "W93_item_door_controller" )
			else
				mission_util.giftItem( sim, unit, "W93_item_scan_pack" )
			end
		else
			mission_util.showBadResult( sim, title, STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_FAILURE )
			sim:trackerAdvance(3)
		end
		currentPlayer:addCPUs(-3)
	else
		mission_util.showNeutralResult( sim, title, string.format(STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_NEUTRAL, unit:getName() ) )
	end
end

---------------------------------------------------------------------------------------------
-- Begin!

local incident = class()

function incident:init( scriptMgr, sim )
	self.scriptMgr = scriptMgr
	scriptMgr:addHook( STRINGS.ITEMSEXTEND.INCIDENTS.ITEM_ORDER_TITLE, hijackConsole, false )
end

return incident
