local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local simfactory = include( "sim/simfactory" )
local mission_util = include( "sim/missions/mission_util" )
local itemdefs = include( "sim/unitdefs/itemdefs" )
---------------------------------------------------------------------------------------------
-- Local helpers

local function isConsolePred( u )
	return u:getTraits().mainframe_console and not u:getTraits().console_incident
end

local function hijackConsole( script, sim )
	local consoleUnit = simquery.findUnit( sim:getAllUnits(), isConsolePred )
	if consoleUnit == nil then
		log:write( "W93_console_scientist_call : no valid console" )
		return
	end

	log:write( "W93_console_scientist_call : unit [%d] at <%d, %d>", consoleUnit:getID(), consoleUnit:getLocation() )
	consoleUnit:getTraits().console_incident = true

	local _, triggerData = script:waitFor( mission_util.PC_HIJACKED( consoleUnit:getID() ))
    	local unit = triggerData.sourceUnit

	local title = STRINGS.ITEMSEXTEND.INCIDENTS.SCIENTIST_CALL_TITLE
	local txt = string.format( STRINGS.ITEMSEXTEND.INCIDENTS.SCIENTIST_CALL_DESC, unit:getName() )
	local options =
	{
		STRINGS.ITEMSEXTEND.INCIDENTS.SCIENTIST_CALL_OPTION1,
		STRINGS.ITEMSEXTEND.INCIDENTS.SCIENTIST_CALL_OPTION2,
		STRINGS.ITEMSEXTEND.INCIDENTS.SCIENTIST_CALL_OPTION3
	}

	local option = mission_util.showDialog( sim, title, txt, options )

	if option == 1 then
		local currentPlayer = sim:getCurrentPlayer()
		if currentPlayer:getCpus() >= 3 and sim:nextRand(1,100) <= 30 then
			mission_util.showGoodResult( sim, title, STRINGS.ITEMSEXTEND.INCIDENTS.SCIENTIST_CALL_SUCCESS )
			local item = nil
			local chance = sim:nextRand(1,4)

			if chance == 1 then
				item = simfactory.createUnit( itemdefs.W93_augment_wmi , sim )
			elseif chance == 2 then
				item = simfactory.createUnit( itemdefs.W93_augment_icebreak, sim)
			elseif chance == 3 then
				item = simfactory.createUnit( itemdefs.augment_distributed_processing, sim)
			else
				item = simfactory.createUnit( itemdefs.augment_net_downlink, sim )
			end
			local scientist = sim:getNPC():spawnGuards(sim, "npc_scientist", 1)
			sim:spawnUnit(item)
			scientist[1]:emptyChildren()
			scientist[1]:addChild( item )
                	sim:getNPC():getIdleSituation():generatePatrolPath( scientist[1] )
                	if scientist[1]:getTraits().patrolPath and #scientist[1]:getTraits().patrolPath > 1 then
				local firstPoint = scientist[1]:getTraits().patrolPath[1]
				scientist[1]:getBrain():getSenses():addInterest(firstPoint.x, firstPoint.y, simdefs.SENSE_RADIO, simdefs.REASON_PATROLCHANGED, scientist[1])
			end
		else
			mission_util.showBadResult( sim, title, STRINGS.ITEMSEXTEND.INCIDENTS.SCIENTIST_CALL_FAILURE )
			sim:getNPC():doTrackerSpawn( sim, 1, "npc_guard_enforcer" )
		end
		currentPlayer:addCPUs(-3)
	elseif option == 2 then
		local hasItem = false

		for i, item in pairs( unit:getChildren() ) do 
			if item:hasAbility( "jackin" ) then
				hasItem = true
			end
		end 
	
		if hasItem then
			mission_util.showGoodResult( sim, title, STRINGS.ITEMSEXTEND.INCIDENTS.SCIENTIST_CALL_SUCCESS )
			local item = nil
			local chance = sim:nextRand(1,4)

			if chance == 1 then
				item = simfactory.createUnit( itemdefs.W93_augment_wmi , sim )
			elseif chance == 2 then
				item = simfactory.createUnit( itemdefs.W93_augment_icebreak, sim)
			elseif chance == 3 then
				item = simfactory.createUnit( itemdefs.augment_distributed_processing, sim)
			else
				item = simfactory.createUnit( itemdefs.augment_net_downlink, sim )
			end
			local scientist = sim:getNPC():spawnGuards(sim, "npc_scientist", 1)
			sim:spawnUnit(item)
			scientist[1]:emptyChildren()
			scientist[1]:addChild( item )
                	sim:getNPC():getIdleSituation():generatePatrolPath( scientist[1] )
                	if scientist[1]:getTraits().patrolPath and #scientist[1]:getTraits().patrolPath > 1 then
				local firstPoint = scientist[1]:getTraits().patrolPath[1]
				scientist[1]:getBrain():getSenses():addInterest(firstPoint.x, firstPoint.y, simdefs.SENSE_RADIO, simdefs.REASON_PATROLCHANGED, scientist[1])
			end
		else
			mission_util.showBadResult( sim, title, STRINGS.ITEMSEXTEND.INCIDENTS.SCIENTIST_CALL_FAILURE )
			sim:getNPC():doTrackerSpawn( sim, 1, "npc_guard_enforcer" )
		end
	elseif option == 3 then
		mission_util.showNeutralResult( sim, title, string.format(STRINGS.ITEMSEXTEND.INCIDENTS.SCIENTIST_CALL_NEUTRAL, unit:getName() ) )
	end
end

---------------------------------------------------------------------------------------------
-- Begin!

local incident = class()

function incident:init( scriptMgr, sim )
	self.scriptMgr = scriptMgr
	scriptMgr:addHook( STRINGS.ITEMSEXTEND.INCIDENTS.SCIENTIST_CALL_TITLE, hijackConsole, false )
end

return incident
