local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local inventory = include("sim/inventory")
local abilityutil = include( "sim/abilities/abilityutil" )

local W93_breakDoor = 
{
	name = STRINGS.ABILITIES.BREAK_DOOR,
	profile_icon = "gui/icons/action_icons/Action_icon_Small/icon-item_sneak_small.png",
	usesAction = true,
	createToolTip = function( self, sim, unit )
		return abilityutil.formatToolTip(STRINGS.ABILITIES.BREAK_DOOR, STRINGS.ABILITIES.BREAK_DOOR_DESC, 0)
	end,
	
	getProfileIcon = function( self, sim, abilityOwner )
		return self.profile_icon
	end,

	getName = function( self, sim, unit )
		return self.name
	end,

        proxy = true,

	acquireTargets = function( self, targets, game, sim, abilityOwner, abilityUser )
		local exits = {}
		local fromCell = sim:getCell( abilityUser:getLocation() )
		local x0,y0 = fromCell.x, fromCell.y
            	local applyFn = abilityOwner:getTraits().applyFn

            	if type(applyFn) == "string" then
			applyFn = simquery[ applyFn ]
		end

		if abilityOwner:getTraits().installed then
			for dir, exit in pairs( fromCell.exits ) do
				if applyFn( exit ) then
					table.insert( exits, { x = fromCell.x, y = fromCell.y, dir = dir } )
				end
			end
		end
		return targets.exitTarget( game, exits, self, abilityOwner, abilityUser )
	end,

	canUseAbility = function( self, sim, unit, abilityUser, x, y, dir )
		local userUnit = unit:getUnitOwner()
		if not userUnit then
			return false
		end

		if x and y then
			local cell = sim:getCell( x, y )
			if not simquery.canModifyExit( abilityUser, simdefs.EXITOP_BREAK_DOOR, cell, dir) then
				return false, STRINGS.ITEMSEXTEND.UI.REASON_DOOR
			end
		end

		if abilityUser:getAP() < 1 then 
			return false, STRINGS.UI.REASON.ATTACK_USED
		end

		if abilityUser:getTraits().mpAttackRestrict and abilityUser:getTraits().mpAttackRestrict > abilityUser:getMP() then
			return false, string.format(STRINGS.FUNCLIB.UI.COMBAT_PANEL_MP, abilityUser:getTraits().mpAttackRestrict)
		end

		if unit:getTraits().cooldown and unit:getTraits().cooldown > 0 then
			return false, util.sformat(STRINGS.UI.REASON.COOLDOWN,unit:getTraits().cooldown)
		end

		if unit:getTraits().pwrCost and userUnit:getPlayerOwner():getCpus() < unit:getTraits().pwrCost then 
			return false,  STRINGS.UI.REASON.NOT_ENOUGH_PWR
		end

		if unit:getTraits().usesCharges and unit:getTraits().charges < 1 then
			return false, util.sformat(STRINGS.UI.REASON.CHARGES)
		end
            
		return abilityutil.checkRequirements( unit, userUnit )
	end,
		
	executeAbility = function( self, sim, unit, userUnit, x0, y0, direction )
		local fromCell = sim:getCell( x0, y0 )
		assert( fromCell and direction )

		userUnit:resetAllAiming()
		simquery.suggestAgentFacing(userUnit, direction)
		if not userUnit:getTraits().noDoorAnim then 
			sim:dispatchEvent( simdefs.EV_UNIT_USEDOOR, { unitID = userUnit:getID(), facing = direction, exitOp=simdefs.EXITOP_BREAK_DOOR } )	
		end
		sim:getPC():glimpseUnit(sim, userUnit:getID() )
		sim:startTrackerQueue(true)				
		sim:startDaemonQueue()			
		sim:dispatchEvent( simdefs.EV_KO_GROUP, true )
		sim:modifyExit(fromCell, direction, simdefs.EXITOP_BREAK_DOOR, userUnit, false)
		if userUnit:isValid() and not userUnit:getTraits().noDoorAnim then
			sim:dispatchEvent( simdefs.EV_UNIT_USEDOOR_PST, { unitID = userUnit:getID(), facing = direction, exitOp=simdefs.EXITOP_BREAK_DOOR } )
		end
		sim:dispatchEvent( simdefs.EV_KO_GROUP, false )
		sim:startTrackerQueue(false)				
		sim:processDaemonQueue()			
		if userUnit:isValid() and not userUnit:getTraits().noDoorAnim and not userUnit:getTraits().interrupted then
			sim:dispatchEvent( simdefs.EV_UNIT_GUNCHECK, { unit = userUnit, facing = direction } )
		end
		userUnit:useAP( sim )
		inventory.useItem( sim, userUnit, unit )
		simquery.LEVER_resetStatus( sim, userUnit, "ANY", false )
	end,
}
return W93_breakDoor