local util = include( "modules/util" )
local mathutil = include( "modules/mathutil" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local speechdefs = include("sim/speechdefs")
local mission_util = include( "sim/missions/mission_util" )
local abilityutil = include( "sim/abilities/abilityutil" )

local W93_centralaugment =
{
	name = STRINGS.ITEMSEXTEND.UI.CENTRAL_AUGMENT_NAME,
	getName = function( self, sim, unit )
		return self.name
	end,

	proxy=true,

	profile_icon = "gui/icons/action_icons/Action_icon_Small/icon-action_chargeweapon_small.png",
	getProfileIcon = function( self, sim, abilityOwner )
		return self.profile_icon
	end,

	createToolTip = function( self,sim, abilityOwner, abilityUser, targetID )
		local targetUnit = sim:getUnit( targetID )
		if targetUnit:getTraits().mainframe_console then
			local headerTxt = STRINGS.ITEMSEXTEND.UI.CENTRAL_AUGMENT_NAME
			local bodyTxt = util.sformat( STRINGS.ITEMSEXTEND.UI.CENTRAL_AUGMENT_DESC, abilityOwner:getTraits().ammo or 0 )
			return abilityutil.formatToolTip( headerTxt, bodyTxt, simdefs.DEFAULT_COST )
		else
			local headerTxt = STRINGS.ITEMSEXTEND.UI.CENTRAL_AUGMENT_NAME2
			local bodyTxt =STRINGS.ITEMSEXTEND.UI.CENTRAL_AUGMENT_DESC2
			return abilityutil.formatToolTip( headerTxt, bodyTxt, simdefs.DEFAULT_COST )	
		end
	end,

	onSpawnAbility = function( self, sim, unit )
        	sim:addTrigger( simdefs.TRG_DAEMON_INSTALL, self )
        	sim:addTrigger( simdefs.TRG_UNIT_HIJACKED, self )
		self.unit = unit
	end,
        
	onDespawnAbility = function( self, sim, unit )
        	sim:removeTrigger( simdefs.TRG_DAEMON_INSTALL, self )
		sim:removeTrigger( simdefs.TRG_UNIT_HIJACKED, self )
		self.unit = nil
	end,

	onTrigger = function( self, sim, evType, evData ) 
        	if evType == simdefs.TRG_DAEMON_INSTALL and self.unit:getUnitOwner() and not self.unit:getUnitOwner():isKO() and self.unit:getTraits().ammo < self.unit:getTraits().maxAmmo then
            		self.unit:getTraits().ammo = math.min(self.unit:getTraits().ammo + 3, self.unit:getTraits().maxAmmo)
        	end
	end,
		
	isTarget = function( self, abilityOwner, unit, targetUnit )
		if not ( (targetUnit:getTraits().mainframe_console and (targetUnit:getTraits().cpus or 0) == 0) or (targetUnit:getTraits().mainframe_ice and (targetUnit:getTraits().mainframe_program or (targetUnit:getSim():getHideDaemons() and not targetUnit:getTraits().daemon_sniffed))) ) then
			return false
		end

		if targetUnit:getTraits().mainframe_status ~= "active" then
			return false
		end

		return true
	end,

	acquireTargets = function( self, targets, game, sim, abilityOwner, unit )
		local x0, y0 = unit:getLocation()
		local units = {}
		for _, targetUnit in pairs(sim:getAllUnits()) do
			local x1, y1 = targetUnit:getLocation()
			if x1 and self:isTarget( abilityOwner, unit, targetUnit ) then
				local range = mathutil.dist2d( x0, y0, x1, y1 )
				if range <= 1 and simquery.isConnected( sim, sim:getCell( x0, y0 ), sim:getCell( x1, y1 ) ) then
					table.insert( units, targetUnit )
				end
			end
		end

		return targets.unitTarget( game, units, self, abilityOwner, unit )
	end,

	canUseAbility = function( self, sim, abilityOwner, unit, targetUnitID )
		if abilityOwner ~= unit and abilityOwner:getUnitOwner() ~= unit then
                	return false
            	end

		local targetUnit = sim:getUnit( targetUnitID )
		if targetUnit then
			if targetUnit:getTraits().mainframe_console then
				if targetUnit:getTraits().mainframe_console_lock > 0 then
					return false, STRINGS.UI.REASON.CONSOLE_LOCKED
				end

				if abilityOwner:getTraits().ammo and abilityOwner:getTraits().ammo < 1 then
					return false, util.sformat(STRINGS.UI.REASON.NO_AMMO)
				end
			elseif targetUnit:getTraits().mainframe_ice then
				if abilityOwner:getTraits().ammo and abilityOwner:getTraits().ammo < 5 then
					return false, util.sformat(STRINGS.UI.REASON.NO_AMMO)
				end
			end
		end		

		return abilityutil.checkRequirements( abilityOwner, unit )
	end,

	executeAbility = function( self, sim, abilityOwner, unit, targetUnitID )
		sim:emitSpeech( unit, speechdefs.EVENT_HIJACK )
		local targetUnit = sim:getUnit( targetUnitID )
		local x1, y1 = targetUnit:getLocation()
    		local x0, y0 = unit:getLocation()
		local facing = simquery.getDirectionFromDelta( x1 - x0, y1 - y0 )
		sim:dispatchEvent( simdefs.EV_UNIT_USECOMP, { unitID = unit:getID(), targetID= targetUnit:getID(), facing = facing, sound=simdefs.SOUNDPATH_USE_CONSOLE, soundFrame=10 } )
		if targetUnit:getTraits().mainframe_console then
			sim:dispatchEvent( simdefs.EV_UNIT_FLY_TXT, {txt=util.sformat(STRINGS.UI.FLY_TXT.PLUS_PWR, abilityOwner:getTraits().ammo), x=x0,y=y0, color={r=163/255,g=243/255,b=248/255,a=1},} )
			sim:getPC():addCPUs( abilityOwner:getTraits().ammo )
			abilityOwner:getTraits().ammo = 0
		else
			if not targetUnit:getTraits().mainframe_program then
				sim:dispatchEvent( simdefs.EV_PLAY_SOUND, simdefs.SOUND_HUD_INCIDENT_NEGATIVE.path )
        			mission_util.showDialog( sim, STRINGS.UI.DIALOGS.NO_DAEMON_TITLE, STRINGS.UI.DIALOGS.NO_DAEMON_BODY )	
				sim:dispatchEvent( simdefs.EV_UNIT_UPDATE_ICE, { unit = targetUnit, ice = targetUnit:getTraits().mainframe_ice, delta = 0} )
				targetUnit:getTraits().daemon_sniffed = true	
			else
				targetUnit:getTraits().daemon_sniffed = true
				targetUnit:getTraits().mainframe_program = nil
				sim:dispatchEvent( simdefs.EV_KILL_DAEMON, {unit = targetUnit})
				if targetUnit:getTraits().daemonHost then
					sim:getUnit(targetUnit:getTraits().daemonHost):killUnit(sim)
					targetUnit:getTraits().daemonHost = nil
				end
				sim:dispatchEvent( simdefs.EV_UNIT_UPDATE_ICE, { unit = targetUnit, ice = targetUnit:getTraits().mainframe_ice, delta = 0} )		
				sim:dispatchEvent( simdefs.EV_PLAY_SOUND, simdefs.SOUND_DAEMON_REVEAL.path )
				abilityOwner:getTraits().ammo = abilityOwner:getTraits().ammo - 5
			end
		end
		simquery.LEVER_resetStatus( sim, unit, "LEGIT", true )
	end,
}

return W93_centralaugment