local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local inventory = include("sim/inventory")
local abilityutil = include( "sim/abilities/abilityutil" )
local mainframe = include( "sim/mainframe" )

local W93_console_use =
{
	name = STRINGS.ITEMSEXTEND.UI.CONSOLE_USE,
	profile_icon = "gui/icons/action_icons/Action_icon_Small/icon-action_chargeweapon_small.png",
	proxy = true,

	createToolTip = function( self,sim, abilityOwner, abilityUser, targetID )
		local targetUnit = sim:getUnit( targetID )
		local headerTxt = STRINGS.ITEMSEXTEND.UI.CONSOLE_USE
		local bodyTxt = string.format( STRINGS.ITEMSEXTEND.UI.CONSOLE_USE_TIP, abilityOwner:getName() )
		return abilityutil.formatToolTip( headerTxt, bodyTxt, simdefs.DEFAULT_COST )
	end,
		
	getName = function( self, sim, unit )
		return STRINGS.ITEMSEXTEND.UI.CONSOLE_USE
	end,

	getProfileIcon = function( self, sim, abilityOwner )
		if abilityOwner then
			return abilityOwner:getTraits().skillIcon
		else
			return self.profile_icon
		end
	end,

	acquireTargets = function( self, targets, game, sim, unit )
		local userUnit = unit:getUnitOwner()
		assert( userUnit, tostring(unit and unit:getName())..", "..tostring(unit:getLocation()) )
		local cell = sim:getCell( userUnit:getLocation() )
        	local cells = { cell }
		for dir, exit in pairs(cell.exits) do
			if simquery.isOpenExit( exit ) then
				table.insert( cells, exit.cell )
			end
		end

		local units = {}
		for i, cell in pairs(cells) do
			for _, cellUnit in ipairs( cell.units ) do
				if cellUnit:getTraits().mainframe_console and cellUnit:getTraits().mainframe_status == "active" then
					table.insert( units, cellUnit )
				end
			end
		end

		return targets.unitTarget( game, units, self, unit, userUnit )
	end,
		
	canUseAbility = function( self, sim, unit )
		local userUnit = unit:getUnitOwner()
		if not userUnit then
			return false
		end
		if not unit:getTraits().installed then
			return false
		end

		if unit:getTraits().cooldown and unit:getTraits().cooldown > 0 then
			return false, util.sformat(STRINGS.UI.REASON.COOLDOWN,unit:getTraits().cooldown)
		end
		if unit:getTraits().usesCharges and unit:getTraits().charges < 1 then
			return false, util.sformat(STRINGS.UI.REASON.CHARGES)
		end
		if unit:getTraits().pwrCost and userUnit:getPlayerOwner():getCpus() < unit:getTraits().pwrCost then
			return false, STRINGS.UI.COMBAT_PANEL_NO_PWR
		end
		if unit:getTraits().effect == "KO" and unit:getTraits().ammo >= unit:getTraits().maxAmmo then
			return false, STRINGS.UI.REASON.AMMO_FULL
		end

        	return abilityutil.checkRequirements( unit, userUnit)
	end,
		
	executeAbility = function( self, sim, abilityOwner, unit, targetUnitID )
		local targetUnit = sim:getUnit( targetUnitID )
		local x1, y1 = targetUnit:getLocation()
    		local x0,y0 = unit:getLocation()
		local facing = simquery.getDirectionFromDelta( x1 - x0, y1 - y0 )
		local params = {color ={{symbol="inner_line",r=0,g=1,b=1,a=0.75},{symbol="wall_digital",r=0,g=1,b=1,a=0.75},{symbol="boxy_tail",r=0,g=1,b=1,a=0.75},{symbol="boxy",r=0,g=1,b=1,a=0.75}} }

		local skillBoost = 0
		if abilityOwner:getTraits().skillBoost then
			skillBoost = unit:getSkillLevel( abilityOwner:getTraits().skillBoost )
		end
		inventory.useItem( sim, unit, abilityOwner )

		sim:dispatchEvent( simdefs.EV_UNIT_USECOMP, { unitID = unit:getID(), targetID = targetUnit:getID(), facing = facing, sound = simdefs.SOUNDPATH_USE_CONSOLE, soundFrame = 10 } )
		sim:dispatchEvent( simdefs.EV_UNIT_ADD_FX, { unit = unit, kanim = "fx/deamon_ko", symbol = "effect", anim="break", above=true, params=params} )

		if abilityOwner:getTraits().effect == "MP" then
			targetUnit:processEMP( abilityOwner:getTraits().rebootTime - skillBoost, true )
			unit:addMP( abilityOwner:getTraits().effectValue )
			sim:dispatchEvent( simdefs.EV_UNIT_FLOAT_TXT, {txt=util.sformat(STRINGS.FORMATS.PLUS_AP, abilityOwner:getTraits().effectValue),x=x1,y=y1,color={r=1,g=1,b=1,a=1}} )
		end
		if abilityOwner:getTraits().effect == "KO" and abilityOwner:getTraits().ammo < abilityOwner:getTraits().maxAmmo then
			targetUnit:processEMP( abilityOwner:getTraits().rebootTime - skillBoost, true )
			abilityOwner:getTraits().ammo = abilityOwner:getTraits().ammo + abilityOwner:getTraits().effectValue + 1
			sim:dispatchEvent( simdefs.EV_UNIT_FLOAT_TXT, {txt=util.sformat(STRINGS.ITEMSEXTEND.UI.CONSOLE_USE_KO, abilityOwner:getTraits().effectValue),x=x1,y=y1,color={r=1,g=1,b=1,a=1}} )
		end
		if abilityOwner:getTraits().effect == "FW" then
			targetUnit:processEMP( abilityOwner:getTraits().rebootTime - skillBoost, true )
			local device = nil
			for i, deviceUnit in pairs(sim:getAllUnits()) do
				if deviceUnit:getTraits().mainframe_ice and deviceUnit:getTraits().mainframe_ice > 0 and not device then
					device = deviceUnit
				elseif deviceUnit:getTraits().mainframe_ice and deviceUnit:getTraits().mainframe_ice > 0 and deviceUnit:getTraits().mainframe_ice > device:getTraits().mainframe_ice then
					device = deviceUnit
				end
			end
			if device then
    				sim:dispatchEvent( simdefs.EV_CAM_PAN, { device:getLocation() } )
				sim:dispatchEvent( simdefs.EV_WAIT_DELAY, 30 )
				mainframe.breakIce( sim, device, abilityOwner:getTraits().effectValue )
			end
		end
		if abilityOwner:getTraits().effect == "CR" then
			targetUnit:getTraits().mainframe_status = "off"
			sim:dispatchEvent( simdefs.EV_UNIT_FLOAT_TXT, {txt=util.sformat(STRINGS.ITEMSEXTEND.UI.CONSOLE_USE_CR, abilityOwner:getTraits().effectValue * skillBoost),x=x1,y=y1,color={r=1,g=1,b=1,a=1}} )
			for i, deviceUnit in pairs(sim:getAllUnits()) do
				if deviceUnit:getTraits().safeUnit and deviceUnit:getTraits().credits and deviceUnit:getTraits().credits > 0 then
					deviceUnit:getTraits().credits = deviceUnit:getTraits().credits + (abilityOwner:getTraits().effectValue * skillBoost)
				end
			end
		end

		sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = targetUnit } )
		simquery.LEVER_resetStatus( sim, unit, "LEGIT", true )
	end,
}

return W93_console_use