local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local inventory = include("sim/inventory")
local abilityutil = include( "sim/abilities/abilityutil" )

local W93_dart_translocator =
{
	name = STRINGS.ITEMSEXTEND.UI.DART_TRANSLOCATOR,
	profile_icon = "gui/icons/action_icons/Action_icon_Small/icon-item_select_small.png",
	proxy = true,

	createToolTip = function( self,sim, abilityOwner, abilityUser, targetID )
		local targetUnit = sim:getUnit( targetID )
		local headerTxt = string.format( STRINGS.ITEMSEXTEND.UI.DART_TRANSLOCATOR, util.toupper( targetUnit:getName() ) )
		local bodyTxt = string.format(STRINGS.ITEMSEXTEND.UI.DART_TRANSLOCATOR_DESC, abilityOwner:getTraits().pwrCost)
		return abilityutil.formatToolTip( headerTxt, bodyTxt, simdefs.DEFAULT_COST )
	end,
		
	getName = function( self, sim, unit )
		return self.name
	end,

	getProfileIcon = function( self, sim, abilityOwner )
		return self.profile_icon
	end,

	acquireTargets = function( self, targets, game, sim, unit )
		local userUnit = unit:getUnitOwner()
		local units = {}
		for _, npcUnit in ipairs( sim:getNPC():getUnits() ) do
			if npcUnit:isKO() and npcUnit:hasTrait("W93_rangedKO") then
				table.insert( units, npcUnit )
			end
		end

		return targets.unitTarget( game, units, self, unit, userUnit )
	end,
		
	canUseAbility = function( self, sim, unit, userUnit, targetID )
		local userUnit = unit:getUnitOwner()
		if not userUnit then
			return false
		end

		if not unit:getTraits().installed then
			return false
		end

		if targetID and simquery.isUnitCellFull( sim, sim:getUnit(targetID) ) then
			return false, STRINGS.UI.REASON.BLOCKED
		end

		if unit:getTraits().cooldown and unit:getTraits().cooldown > 0 then
			return false, util.sformat(STRINGS.UI.REASON.COOLDOWN,unit:getTraits().cooldown)
		end

		if unit:getTraits().pwrCost and unit:getPlayerOwner():getCpus() < unit:getTraits().pwrCost then
			return false, STRINGS.UI.COMBAT_PANEL_NO_PWR
		end

        	return abilityutil.checkRequirements( unit, userUnit)
	end,
		
	executeAbility = function( self, sim, unit, userUnit, targetID )
		local userUnit = unit:getUnitOwner()
		local target = sim:getUnit(targetID)			
			
		local cell = sim:getCell(target:getLocation())
		local x1,y1 = target:getLocation()
		sim:dispatchEvent( simdefs.EV_UNIT_APPEARED, { unitID = userUnit:getID(), noSightingFx=true } )
		sim:dispatchEvent( simdefs.EV_TELEPORT, { units={userUnit}, warpOut = true } )
		sim:warpUnit( userUnit, cell )
		sim:dispatchEvent( simdefs.EV_UNIT_APPEARED, { unitID = userUnit:getID(), noSightingFx=true } )
		sim:dispatchEvent( simdefs.EV_TELEPORT, { units={userUnit}, warpOut =false } )
		sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = userUnit } )
		sim:processReactions()
		inventory.useItem( sim, userUnit, unit )
		sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = userUnit  } )
		simquery.LEVER_resetStatus( sim, userUnit, "LEGIT", true )
	end,
}

return W93_dart_translocator