local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local inventory = include("sim/inventory")
local abilityutil = include( "sim/abilities/abilityutil" )

local W93_doorControllerUse = 
{
	createToolTip = function( self,sim,unit,targetCell)
		return abilityutil.formatToolTip( STRINGS.ITEMSEXTEND.UI.DOOR_CONTROLLER_USE, STRINGS.ITEMSEXTEND.UI.DOOR_CONTROLLER_USE_TIP, simdefs.DEFAULT_COST )
	end,

	profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_scan_pack_small.png",
		
	getProfileIcon = function( self, sim, abilityOwner )
		return self.profile_icon
	end,

        proxy = true,

	getName = function( self, sim, unit )
		return string.format(STRINGS.ABILITIES.SET_NAME,unit:getName())
	end,

	acquireTargets = function( self, targets, game, sim, abilityOwner, abilityUser )
		local exits = {}
		if abilityOwner:getTraits().cooldown <= 0 then
			local fromCell = sim:getCell( abilityUser:getLocation() )
			local applyFn = "isDoorExit"
            		local cells = simquery.rasterCircle( sim, fromCell.x, fromCell.y, abilityOwner:getTraits().range )

			if type(applyFn) == "string" then
				applyFn = simquery[ applyFn ]
			end
	
			for i, x, y in util.xypairs( cells ) do
                		local cell = sim:getCell( x, y )
				if cell and sim:getPC():getLastKnownCell( sim, x, y ) ~= nil then
					for dir, exit in pairs( cell.exits ) do
						if applyFn( exit ) and (exit.remote or abilityOwner:getTraits().W93_DoorAugment and not exit.remote2 ) then
							if abilityOwner:getTraits().W93_DoorAugment and not exit.remote2 then
								exit.cell.exits[simquery.getReverseDirection( dir )].remote2 = true
							end
							table.insert( exits, { x = x, y = y, dir = dir } )
						end
					end
				end
			end
		end

		return targets.exitTarget( game, exits, self, abilityOwner, abilityUser )
	end,

	canUseAbility = function( self, sim, unit, abilityUser, x, y, dir )
		local userUnit = unit:getUnitOwner()
		if not userUnit then
			return false
		end

		if unit:getTraits().cooldown and unit:getTraits().cooldown > 0 then
			return false, util.sformat(STRINGS.UI.REASON.COOLDOWN,unit:getTraits().cooldown)
		end

		--if unit:getTraits().W93_DoorAugment and not unit:getTraits().installed then
		--	return false, STRINGS.ITEMSEXTEND.UI.REASON_NOT_INSTALLED
		--end

		local fromCell = sim:getCell( x, y )
		if fromCell and (fromCell.exits[ dir ].locked or (fromCell.exits[ dir ].keybits > simdefs.DOOR_KEYS.SECURITY and fromCell.exits[ dir ].keybits < simdefs.DOOR_KEYS.SPECIAL_EXIT)) then
			return false, STRINGS.UI.DOORS.LOCKED
		end

		return abilityutil.checkRequirements( unit, userUnit )
	end,
		
	executeAbility = function( self, sim, unit, userUnit, x0, y0, dir )
		local fromCell = sim:getCell( x0, y0 )
		assert( fromCell and dir )

		if fromCell.exits[ dir ].remote or unit:getTraits().W93_DoorAugment then
        		if simquery.isClosedDoor( fromCell.exits[ dir ] ) and not fromCell.exits[ dir ].locked then
            			sim:modifyExit( fromCell, dir, simdefs.EXITOP_OPEN, userUnit, userUnit:getTraits().sneaking )
			elseif simquery.isOpenExit( fromCell.exits[ dir ] ) and not fromCell.exits[ dir ].locked then
            			sim:modifyExit( fromCell, dir, simdefs.EXITOP_CLOSE, userUnit, userUnit:getTraits().sneaking )
        		end
			if unit:getTraits().cooldown and unit:getTraits().cooldownMax then
				unit:getTraits().cooldown = unit:getTraits().cooldownMax
			end
		end
		simquery.LEVER_resetStatus( sim, userUnit, "LEGIT", true )
	end,
}
return W93_doorControllerUse