local util = include( "modules/util" )
local array = include( "modules/array" )
local simunit = include( "sim/simunit" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local simfactory = include( "sim/simfactory" )
local unitdefs  = include( "sim/unitdefs" )
local mathutil = include( "modules/mathutil" )

-----------------------------------------------------
-- Local functions

local W93_door_controller = { ClassType = "W93_door_controller" }

function W93_door_controller:onWarp( sim, oldcell, cell )
	if oldcell == nil and cell ~= nil then
		if not cell.exits[ self:getFacing() ].cell.exits[simquery.getReverseDirection( self:getFacing() )].remote then
			cell.exits[ self:getFacing() ].remote = true
		end
		--sim:addTrigger( simdefs.TRG_UNIT_USEDOOR, self )

	elseif oldcell ~= nil and cell == nil then
		oldcell.exits[ self:getFacing() ].remote = nil
		oldcell.exits[ self:getFacing() ].trapped = nil
		--sim:removeTrigger( simdefs.TRG_UNIT_USEDOOR, self )
	end
end

function W93_door_controller:onTrigger( sim, evType, evData )
	if evType == simdefs.TRG_UNIT_USEDOOR then
		local cell = sim:getCell( self:getLocation() )
		if evData.cell == cell or evData.tocell == cell then
			--cell.exits[ self:getFacing() ].remote = nil
            		--sim:warpUnit( self, nil ) -- Just remove.
            		--sim:despawnUnit( self )
		end
	end
end

-----------------------------------------------------
-- Interface functions
local function applyToDoor( sim, cell, direction, unit, userUnit )
	assert( simquery.isClosedDoor( cell.exits[ direction ] ))
    	local toCell = cell.exits[ direction ].cell
    	local rdir = simquery.getReverseDirection( direction )

	local controller1 = simfactory.createUnit( unitdefs.prop_templates.W93_door_controller, sim )
	controller1:setFacing( direction )
	sim:spawnUnit( controller1 )
	sim:warpUnit( controller1, cell)
	controller1:setPlayerOwner(userUnit:getPlayerOwner())
	
	local controller2 = simfactory.createUnit( unitdefs.prop_templates.W93_door_controller, sim )
	controller2:setFacing( rdir )
	sim:spawnUnit( controller2 )
	sim:warpUnit( controller2, toCell )
	controller2:setPlayerOwner(userUnit:getPlayerOwner())

	controller1:getTraits().linkedTrap = controller2:getID()
	controller2:getTraits().linkedTrap = controller1:getID()

    	cell.exits[ direction ].trapped = true
    	toCell.exits[ rdir ].trapped = true
end

local function createDoorController( unitData, sim )
	return simunit.createUnit( unitData, sim, W93_door_controller )
end

simfactory.register( createDoorController )

return
{
	applyToDoor = applyToDoor,
}