local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local inventory = include("sim/inventory")
local abilityutil = include( "sim/abilities/abilityutil" )

local W93_drone_toolkit_AP =
{
	name = STRINGS.ITEMSEXTEND.UI.DRONE_TOOLKIT,
	profile_icon = "gui/icons/skills_icons/skills_icon_small/icon-item_analyze_small.png",
	proxy = true,

	createToolTip = function( self,sim, abilityOwner, abilityUser, targetID )
		local targetUnit = sim:getUnit( targetID )
		local headerTxt = string.format( STRINGS.ITEMSEXTEND.UI.DRONE_TOOLKIT_FIREWALL, util.toupper( targetUnit:getName() ) )
		local bodyTxt = util.sformat( STRINGS.ITEMSEXTEND.UI.DRONE_TOOLKIT_FIREWALL_DESC, abilityOwner:getTraits().reduceFirewall )
		return abilityutil.formatToolTip( headerTxt, bodyTxt, simdefs.DEFAULT_COST )
	end,
		
	getName = function( self, sim, unit )
		return STRINGS.ITEMSEXTEND.UI.DRONE_TOOLKIT
	end,

	getProfileIcon = function( self, sim, abilityOwner )
		return self.profile_icon
	end,

	acquireTargets = function( self, targets, game, sim, unit )
		local userUnit = unit:getUnitOwner()
		assert( userUnit, tostring(unit and unit:getName())..", "..tostring(unit:getLocation()) )
		local cell = sim:getCell( userUnit:getLocation() )
        	local cells = { cell }
		for dir, exit in pairs(cell.exits) do
			if simquery.isOpenExit( exit ) then
				table.insert( cells, exit.cell )
			end
		end

		local units = {}
		for i, cell in pairs(cells) do
			for _, cellUnit in ipairs( cell.units ) do
				if (cellUnit:getTraits().mainframe_ice or 0) > 1 and cellUnit:getTraits().isDrone then
					table.insert( units, cellUnit )
				end
			end
		end

		return targets.unitTarget( game, units, self, unit, userUnit )
	end,
		
	canUseAbility = function( self, sim, unit )

		-- Must have a user owner.
		local userUnit = unit:getUnitOwner()
		if not userUnit then
			return false
		end
		if unit:getTraits().cooldown and unit:getTraits().cooldown > 0 then
			return false, util.sformat(STRINGS.UI.REASON.COOLDOWN,unit:getTraits().cooldown)
		end
		if unit:getTraits().usesCharges and unit:getTraits().charges < 1 then
			return false, util.sformat(STRINGS.UI.REASON.CHARGES)
		end
		
        	return abilityutil.checkRequirements( unit, userUnit)
	end,
		
	executeAbility = function( self, sim, unit, userUnit, target )
		local userUnit = unit:getUnitOwner()
		local target = sim:getUnit(target)			
			
		local x0,y0 = userUnit:getLocation()
		local x1,y1 = target:getLocation()
  		local newFacing = simquery.getDirectionFromDelta(x1-x0,y1-y0) 
		local params = {color ={{symbol="inner_line",r=0,g=1,b=1,a=0.75},{symbol="wall_digital",r=0,g=1,b=1,a=0.75},{symbol="boxy_tail",r=0,g=1,b=1,a=0.75},{symbol="boxy",r=0,g=1,b=1,a=0.75}} }


		sim:dispatchEvent( simdefs.EV_UNIT_USECOMP, { unitID = userUnit:getID(), facing = newFacing, sound=simdefs.SOUNDPATH_USE_CONSOLE, soundFrame=10 } )
		sim:dispatchEvent( simdefs.EV_WAIT_DELAY, 60*0.65)
		sim:dispatchEvent( simdefs.EV_UNIT_ADD_FX, { unit = target, kanim = "fx/deamon_ko", symbol = "effect", anim="break", above=true, params=params} )
		sim:dispatchEvent( simdefs.EV_UNIT_FLOAT_TXT, {txt=util.sformat(STRINGS.ITEMSEXTEND.UI.DRONE_TOOLKIT_FIREWALL_TXT,unit:getTraits().reduceFirewall),x=x1,y=y1,color={r=1,g=1,b=1,a=1}} )
		
		if unit:getTraits().reduceFirewall and target:getTraits().mainframe_ice and target:getTraits().mainframe_iceMax then
			target:getTraits().mainframe_iceMax = math.max(1,target:getTraits().mainframe_iceMax - unit:getTraits().reduceFirewall)
			if target:getTraits().mainframe_ice > target:getTraits().mainframe_iceMax then
				target:getTraits().mainframe_ice = target:getTraits().mainframe_iceMax
			end
		end

		inventory.useItem( sim, userUnit, unit )

		if userUnit:isValid() then
			sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = userUnit  } )
		end
		simquery.LEVER_resetStatus( sim, userUnit, "LEGIT", true )
	end,
}

return W93_drone_toolkit_AP