local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local inventory = include("sim/inventory")
local abilityutil = include( "sim/abilities/abilityutil" )

local BROKEN_FIREWALLS = 2

local W93_manual_ice_break =
{
	name = STRINGS.ITEMSEXTEND.UI.MANUAL_OVERRIDE,
	profile_icon = "gui/icons/skills_icons/skills_icon_small/icon-item_augment_tony_small.png",
	usesAction = true,

	createToolTip = function( self,sim, abilityOwner, abilityUser, targetID )
		local targetUnit = sim:getUnit( targetID )
		local headerTxt = string.format( STRINGS.ITEMSEXTEND.UI.MANUAL_OVERRIDE_HEADER, util.toupper( targetUnit:getName() ) )
		local bodyTxt = string.format( STRINGS.ITEMSEXTEND.UI.MANUAL_OVERRIDE_TIP, BROKEN_FIREWALLS )
		return abilityutil.formatToolTip( headerTxt, bodyTxt, simdefs.DEFAULT_COST )
	end,
		
	getName = function( self, sim, unit )
		return STRINGS.ITEMSEXTEND.UI.MANUAL_OVERRIDE
	end,

    	isTarget = function( self, sim, userUnit, targetUnit )
        	if (targetUnit:getTraits().mainframe_ice or 0) > 0 and (targetUnit:getTraits().mainframe_status ~= "off" or (targetUnit:getTraits().mainframe_camera and targetUnit:getTraits().mainframe_booting)) then
            		if sim:canUnitSeeUnit( userUnit, targetUnit ) and (not targetUnit:getTraits().isDrone or not targetUnit:isKO()) then
                		return true
            		end
        	end

        	return false
    	end,

	acquireTargets = function( self, targets, game, sim, unit, userUnit )
		local cell = sim:getCell( userUnit:getLocation() )
		local units = {}
		for dir, exit in pairs(cell.exits) do
			for _, cellUnit in ipairs( exit.cell.units ) do
                		if self:isTarget( sim, userUnit, cellUnit ) and simquery.canUnitReach( sim, userUnit, exit.cell.x, exit.cell.y ) then
					table.insert( units, cellUnit )
				end
			end
		end

		return targets.unitTarget( game, units, self, unit, userUnit )
	end,
		
	canUseAbility = function( self, sim, unit, userUnit )
		local cell = sim:getCell( userUnit:getLocation() )
		local count = 0
		for dir, exit in pairs(cell.exits) do
			local unit = array.findIf( exit.cell.units, function( u ) return self:isTarget( sim, userUnit, u ) end )
			if unit then
				count = count + 1
			end					
		end

		if unit:getAP() < 1 then 
			return false, STRINGS.UI.REASON.ATTACK_USED
		end

		if unit:getTraits().mpAttackRestrict and unit:getTraits().mpAttackRestrict > unit:getMP() then
			return false, string.format(STRINGS.FUNCLIB.UI.COMBAT_PANEL_MP, unit:getTraits().mpAttackRestrict)
		end

		if unit:getTraits().cooldown and unit:getTraits().cooldown > 0 then
			return false, string.format(STRINGS.UI.REASON.COOLDOWN,unit:getTraits().cooldown)
		end

		if count == 0 then
			return false, STRINGS.UI.REASON.NO_ICE
		end

		return abilityutil.checkRequirements( unit, userUnit)
	end,
		
	executeAbility = function( self, sim, unit, userUnit, target )
		local mainframe = include( "sim/mainframe" )
		local target = sim:getUnit(target)			
		local x0,y0 = userUnit:getLocation()
		local x1,y1 = target:getLocation()
  		local newFacing = simquery.getDirectionFromDelta(x1-x0,y1-y0) 
		userUnit:setInvisible(false)
		userUnit:setDisguise(false)
		sim:dispatchEvent( simdefs.EV_UNIT_USECOMP, { unitID = unit:getID(), facing = newFacing, sound="SpySociety/Actions/use_scanchip", soundFrame=10 } )			
		mainframe.breakIce( sim, target, BROKEN_FIREWALLS )
		inventory.useItem( sim, userUnit, unit )
		unit:useAP( sim )
		simquery.LEVER_resetStatus( sim, userUnit, "LEGIT", true )
	end,
}
return W93_manual_ice_break