local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local inventory = include("sim/inventory")
local abilityutil = include( "sim/abilities/abilityutil" )

local W93_neural_data_extract =
{
	name = STRINGS.ITEMSEXTEND.UI.NEURAL_DATA_EXTRACT,
	profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_neural_data_extractor_small.png",
	proxy = true,
	usesAction = true,

	createToolTip = function( self,sim, abilityOwner, abilityUser, targetID )
		local targetUnit = sim:getUnit( targetID )
		local headerTxt = string.format( STRINGS.ITEMSEXTEND.UI.NEURAL_DATA_EXTRACT, util.toupper( targetUnit:getName() ) )
		local bodyTxt = STRINGS.ITEMSEXTEND.UI.NEURAL_DATA_EXTRACT_DESC
		return abilityutil.formatToolTip( headerTxt, bodyTxt, simdefs.DEFAULT_COST )
	end,
		
	getName = function( self, sim, unit )
		return string.format( self.name, "NOBODY" )
	end,

	getProfileIcon = function( self, sim, abilityOwner )
		return self.profile_icon
	end,

	acquireTargets = function( self, targets, game, sim, unit )
		local userUnit = unit:getUnitOwner()
		assert( userUnit, tostring(unit and unit:getName())..", "..tostring(unit:getLocation()) )
		local cell = sim:getCell( userUnit:getLocation() )

		local units = {}
		for _, cellUnit in ipairs( cell.units ) do
			if cellUnit:getTraits().isGuard and not cellUnit:getTraits().isDrone and cellUnit:getTraits().W93_rangedKO and cellUnit:isKO() and not cellUnit:getTraits().W93_data_extracted then
				local pinning, pinnee = simquery.isUnitPinning(sim, userUnit)
				if pinnee == cellUnit then
					table.insert( units, cellUnit )
				end
			end
		end

		return targets.unitTarget( game, units, self, unit, userUnit )
	end,
		
	canUseAbility = function( self, sim, unit )
		local userUnit = unit:getUnitOwner()
		if not userUnit then
			return false
		end
		if unit:getTraits().cooldown and unit:getTraits().cooldown > 0 then
			return false, util.sformat(STRINGS.UI.REASON.COOLDOWN,unit:getTraits().cooldown)
		end
		if unit:getTraits().usesCharges and unit:getTraits().charges < 1 then
			return false, util.sformat(STRINGS.UI.REASON.CHARGES)
		end
		if unit:getTraits().pwrCost and userUnit:getPlayerOwner():getCpus() < unit:getTraits().pwrCost then 
			return false,  STRINGS.UI.REASON.NOT_ENOUGH_PWR
		end
		if userUnit:getAP() < 1 then 
			return false, STRINGS.UI.REASON.ATTACK_USED
		end
		if userUnit:getTraits().mpAttackRestrict and userUnit:getTraits().mpAttackRestrict > userUnit:getMP() then
			return false, string.format(STRINGS.FUNCLIB.UI.COMBAT_PANEL_MP, userUnit:getTraits().mpAttackRestrict)
		end
        	return abilityutil.checkRequirements( unit, userUnit)
	end,
		
	executeAbility = function( self, sim, unit, userUnit, target )
		local userUnit = unit:getUnitOwner()
		local targetUnit = sim:getUnit(target)			
		local x0,y0 = userUnit:getLocation()

		sim:dispatchEvent( simdefs.EV_UNIT_MELEE, { unit = userUnit, targetUnit = targetUnit, grapple = false, pinning = true, lethal = false} )
		sim:dispatchEvent( simdefs.EV_UNIT_HIT, {unit = targetUnit, taze=true} )
		sim:dispatchEvent( simdefs.EV_UNIT_MELEE, { finishMelee=true })
		sim:dispatchEvent( simdefs.EV_WAIT_DELAY, 60*0.65)

		if unit:getTraits().crExtractMin and unit:getTraits().crExtractMax then
			local cr = sim:nextRand(unit:getTraits().crExtractMin, unit:getTraits().crExtractMax)
			sim:dispatchEvent( simdefs.EV_PLAY_SOUND, "SpySociety/HUD/gameplay/gain_money")
			userUnit:getPlayerOwner():addCredits(cr, sim, x0, y0)
			targetUnit:getTraits().W93_data_extracted = true
		end

		inventory.useItem( sim, userUnit, unit )
		userUnit:useAP( sim )
		if userUnit:isValid() then
			sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = userUnit  } )
		end
		simquery.LEVER_resetStatus( sim, userUnit, "ANY", false )
	end,
}

return W93_neural_data_extract