local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local inventory = include("sim/inventory")
local abilityutil = include( "sim/abilities/abilityutil" )

local W93_paralyze =
{
	name = STRINGS.ITEMSEXTEND.UI.PARALYZE,
	profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_paralyzerdose_small.png",
	proxy = true,
	paralyzeTarget = {},

	createToolTip = function( self,sim, abilityOwner, abilityUser, targetID )
		local targetUnit = sim:getUnit( targetID )
		local headerTxt = string.format( STRINGS.ITEMSEXTEND.UI.PARALYZE, util.toupper( targetUnit:getName() ) )
		local bodyTxt = util.sformat( STRINGS.ITEMSEXTEND.UI.PARALYZE_DESC, abilityOwner:getTraits().koTime )
		return abilityutil.formatToolTip( headerTxt, bodyTxt, simdefs.DEFAULT_COST )
	end,
		
	getName = function( self, sim, unit )
		return STRINGS.ITEMSEXTEND.UI.PARALYZE
	end,

	getProfileIcon = function( self, sim, abilityOwner )
		return self.profile_icon
	end,

	onSpawnAbility = function( self, sim )
		sim:addTrigger( simdefs.TRG_START_TURN, self )		
	end,

	onDespawnAbility = function( self, sim )
		sim:removeTrigger( simdefs.TRG_START_TURN, self )		
	end,

  	isTarget = function( self, targetUnit )
		if not targetUnit:getTraits().isGuard then
			return false
		end         		

		if targetUnit:getTraits().isDrone then
			return false
		end 
			
		if targetUnit:isKO() or targetUnit:isDead() then
			return false
		end

            	return true
        end,

	acquireTargets = function( self, targets, game, sim, unit )
		local userUnit = unit:getUnitOwner()
		assert( userUnit, tostring(unit and unit:getName())..", "..tostring(unit:getLocation()) )
		local cell = sim:getCell( userUnit:getLocation() )
        	local cells = { cell }
		for dir, exit in pairs(cell.exits) do
			if simquery.isOpenExit( exit ) then
				table.insert( cells, exit.cell )
			end
		end

		local units = {}
		for i, cell in pairs(cells) do
			for _, cellUnit in ipairs( cell.units ) do
				if self:isTarget(cellUnit) then
					table.insert( units, cellUnit )
				end
			end
		end

		return targets.unitTarget( game, units, self, unit, userUnit )
	end,
		
	canUseAbility = function( self, sim, unit )

		-- Must have a user owner.
		local userUnit = unit:getUnitOwner()
		if not userUnit then
			return false
		end
		if unit:getTraits().cooldown and unit:getTraits().cooldown > 0 then
			return false, util.sformat(STRINGS.UI.REASON.COOLDOWN,unit:getTraits().cooldown)
		end
		if unit:getTraits().usesCharges and unit:getTraits().charges < 1 then
			return false, util.sformat(STRINGS.UI.REASON.CHARGES)
		end
		
        	return abilityutil.checkRequirements( unit, userUnit)
	end,
		
	executeAbility = function( self, sim, unit, userUnit, target )
		local userUnit = unit:getUnitOwner()
		local target = sim:getUnit(target)	
		local x0,y0 = userUnit:getLocation()
		local x1,y1 = target:getLocation()
		local newFacing = simquery.getDirectionFromDelta(x1-x0,y1-y0)

		local guardData = { target }

		if target:getTraits().hasSight then
			table.insert(guardData, true)
			target:getTraits().hasSight = false
		else
			table.insert(guardData, false)
		end
		if target:getTraits().hasHearing then
			table.insert(guardData, true)
			target:getTraits().hasHearing = false
		else
			table.insert(guardData, false)
		end
		if target:getTraits().LOSperipheralRange then
			table.insert(guardData, target:getTraits().LOSperipheralRange)
			target:getTraits().LOSperipheralRange = 0.5
		else
			table.insert(guardData, false)
		end
		if target:getTraits().LOSrange then
			table.insert(guardData, target:getTraits().LOSrange)
			target:getTraits().LOSrange = 0.5
		else
			table.insert(guardData, false)
		end

		table.insert(self.paralyzeTarget,guardData)

		sim:refreshUnitLOS( target )
		simquery.suggestAgentFacing(userUnit, newFacing)
		sim:dispatchEvent( simdefs.EV_UNIT_HEAL, { unit = userUnit, target = target, revive = false, facing = userUnit:getFacing() } )
		sim:dispatchEvent( simdefs.EV_UNIT_FLOAT_TXT, {txt=STRINGS.UI.FLY_TXT.PARALYZED,x=x0,y=y0,color={r=1,g=1,b=0,a=1}} )
		sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = target } )

		if unit:getTraits().disposable then 
			inventory.trashItem( sim, userUnit, unit )
		else
			inventory.useItem( sim, userUnit, unit )
		end

		if userUnit:isValid() then
			sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = userUnit  } )
		end

		sim:triggerEvent( simdefs.TRG_UNIT_PARALYZED )
		simquery.LEVER_resetStatus( sim, userUnit, "ANY", false )
	end,

	onTrigger = function( self, sim, evType, evData )
    		local player = sim:getCurrentPlayer()
    		if player:isPC() and self.paralyzeTarget then
			for i, unit in pairs(self.paralyzeTarget) do
				if unit[2] then
					unit[1]:getTraits().hasSight = true
				end
				if unit[3] then
					unit[1]:getTraits().hasHearing = true
				end
				if unit[4] then
					unit[1]:getTraits().LOSperipheralRange = unit[4]
				end
				if unit[5] then
					unit[1]:getTraits().LOSrange = unit[5]
				end
				sim:refreshUnitLOS( unit[1] )
				sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = unit[1] } )
			end
			util.tclear(self.paralyzeTarget)
		end
	end,
}

return W93_paralyze