local util = include( "modules/util" )
local mathutil = include( "modules/mathutil" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local speechdefs = include("sim/speechdefs")
local inventory = include("sim/inventory")
local mission_util = include( "sim/missions/mission_util" )
local abilityutil = include( "sim/abilities/abilityutil" )

local W93_reprime =
{
	name = STRINGS.ITEMSEXTEND.UI.REPRIME,
	getName = function( self, sim, unit )
		return self.name
	end,
	usesAction = true,
	proxy=true,

	profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_chip_reprime_small.png",
	getProfileIcon = function( self, sim, abilityOwner )
		return self.profile_icon
	end,

	createToolTip = function( self,sim, abilityOwner, abilityUser, targetID )
		local targetUnit = sim:getUnit( targetID )
		local headerTxt = abilityOwner:getName()
		local bodyTxt = util.sformat( STRINGS.ITEMSEXTEND.UI.REPRIME_DESC, abilityOwner:getTraits().reprimeTime or 1, abilityOwner:getTraits().reprimePWR or 1 )
		return abilityutil.formatToolTip( headerTxt, bodyTxt, simdefs.DEFAULT_COST )	
	end,
		
	isTarget = function( self, sim, abilityOwner, targetUnit )
		if not targetUnit:getTraits().mainframe_console then
			return false
		end

		if targetUnit:getTraits().mainframe_status ~= "active" then
			return false
		end

		return true
	end,

	acquireTargets = function( self, targets, game, sim, abilityOwner, unit )
		local cell = sim:getCell( unit:getLocation() )
		local units = {}

		if abilityOwner:getUnitOwner() == unit then
			for dir, exit in pairs(cell.exits) do
				for _, cellUnit in ipairs( exit.cell.units ) do
                			if self:isTarget( sim, unit, cellUnit ) and simquery.canUnitReach( sim, unit, exit.cell.x, exit.cell.y ) then
						table.insert( units, cellUnit )
					end
				end
			end
		end

		return targets.unitTarget( game, units, self, abilityOwner, unit )
	end,

	canUseAbility = function( self, sim, abilityOwner, unit, targetUnitID )
		if not abilityOwner or not unit then
                	return false
            	end

		if unit:getAP() < 1 then 
			return false, STRINGS.UI.REASON.ATTACK_USED
		end

		if unit:getTraits().mpAttackRestrict and unit:getTraits().mpAttackRestrict > unit:getMP() then
			return false, string.format(STRINGS.FUNCLIB.UI.COMBAT_PANEL_MP, unit:getTraits().mpAttackRestrict)
		end

		local targetUnit = sim:getUnit( targetUnitID )
		if targetUnit then
			if (targetUnit:getTraits().cpus or 0) ~= 0 or targetUnit:getTraits().hijacked == false then
				return false, STRINGS.ITEMSEXTEND.UI.REASON_NOT_HIJACKED
			end
		end		

		if abilityOwner:getTraits().cooldown and abilityOwner:getTraits().cooldown > 0 then
			return false, util.sformat(STRINGS.UI.REASON.COOLDOWN, abilityOwner:getTraits().cooldown)
		end
		if abilityOwner:getTraits().usesCharges and abilityOwner:getTraits().charges < 1 then
			return false, util.sformat(STRINGS.UI.REASON.CHARGES)
		end
		if abilityOwner:getTraits().pwrCost and unit:getPlayerOwner():getCpus() < abilityOwner:getTraits().pwrCost then
			return false, STRINGS.UI.COMBAT_PANEL_NO_PWR
		end

		return abilityutil.checkRequirements( abilityOwner, unit )
	end,

	executeAbility = function( self, sim, abilityOwner, unit, targetUnitID )
		sim:emitSpeech( unit, speechdefs.EVENT_HIJACK )
		local targetUnit = sim:getUnit( targetUnitID )
		local x1, y1 = targetUnit:getLocation()
    		local x0, y0 = unit:getLocation()
		local facing = simquery.getDirectionFromDelta( x1 - x0, y1 - y0 )
		sim:dispatchEvent( simdefs.EV_UNIT_USECOMP, { unitID = unit:getID(), targetID= targetUnit:getID(), facing = facing, sound=simdefs.SOUNDPATH_USE_CONSOLE, soundFrame=10 } )

		targetUnit:getTraits().cpus = abilityOwner:getTraits().reprimePWR or 1
		targetUnit:getTraits().hijacked = false
		targetUnit:getTraits().noPWRconvert = true
		targetUnit:processEMP( abilityOwner:getTraits().reprimeTime or 1 )
		targetUnit:setPlayerOwner(sim:getNPC())
		sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = targetUnit } )
		unit:useAP( sim )
		inventory.useItem( sim, unit, abilityOwner )
		simquery.LEVER_resetStatus( sim, unit, "LEGIT", true )
	end,
}

return W93_reprime