local array = include( "modules/array" )
local util = include( "modules/util" )
local mathutil = include( "modules/mathutil" )
local cdefs = include( "client_defs" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local abilityutil = include( "sim/abilities/abilityutil" )

local wireless_scan =
{
	name = STRINGS.ABILITIES.WIRELESS_SCAN,
	getName = function( self, sim, unit )
		return self.name
	end,
		
	onSpawnAbility = function( self, sim, unit )
        	self.abilityOwner = unit
        	sim:addTrigger( simdefs.TRG_UNIT_WARP, self )
	end,
        
	onDespawnAbility = function( self, sim, unit )
        	sim:removeTrigger( simdefs.TRG_UNIT_WARP, self )
        	self.abilityOwner = nil
	end,

	canUseAbility = function( self, sim, abilityOwner, abilityUser )
		if not abilityOwner:getTraits().installed then
			return false
		end

        	return abilityutil.checkRequirements( abilityOwner, abilityUser )
    	end,

    	onTrigger = function( self, sim, evType, evData )
        	if self.abilityOwner and evData.unit == self.abilityOwner:getUnitOwner() and evData.unit:getPlayerOwner() and evData.from_cell and evData.to_cell then
            		if self:canUseAbility( sim, self.abilityOwner, evData.unit ) then
                		self:performScan( sim, self.abilityOwner, evData.to_cell )
            		end
        	end
    	end,
	
	performScan = function( self, sim, abilityOwner, cell )
        	local cells = simquery.rasterCircle( sim, cell.x, cell.y, abilityOwner:getTraits().range )

		for i, x, y in util.xypairs( cells ) do
                	local targetCell = sim:getCell( x, y )
			if targetCell then
				sim:getPC():glimpseCell( sim, targetCell )
				for i, unit in ipairs(targetCell.units) do
					sim:getPC():glimpseUnit( sim, unit:getID() )
					if not unit:getTraits().scanned then
						unit:getTraits().scanned = true
						sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = unit, reveal = true } )
					end 
				end
			end
		end
	end,
}

return wireless_scan