local util = include( "modules/util" )
local commondefs = include( "sim/unitdefs/commondefs" )
local simdefs = include( "sim/simdefs" )

local augment_templates = {
	augment_distributed_processing = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.DISTRIBUTED_PROCESSING,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.DISTRIBUTED_PROCESSING_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.DISTRIBUTED_PROCESSING_FLAVOR, 
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			stackable = true,
			grafterWeight = 10,
		},
		value = 300,			
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_head_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_head.png",			
	},

	augment_skeletal_suspension = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMS.AUGMENTS.SKELETAL_SUSPENSION,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.SKELETAL_SUSPENSION_TIP,
		flavor = STRINGS.ITEMS.AUGMENTS.SKELETAL_SUSPENSION_FLAVOR, 		
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			modTrait = {{"dragCostMod", 0.5}},
			cooldown = 0,
			cooldownMax = 2,
			mpRestored = 3,	
			grafterWeight = 10,
		},				
		value = 300, 
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_arm_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_arm.png",    			
	},

	augment_subdermal_cloak = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMS.AUGMENTS.SUBDERMAL_CLOAK,
		desc = STRINGS.ITEMS.AUGMENTS.SUBDERMAL_CLOAK_TIP, 
		flavor = STRINGS.ITEMS.AUGMENTS.SUBDERMAL_CLOAK_FLAVOR,
		keyword = "STIM", 
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			pwrCost = 3,
			grafterWeight = 5,
		},			
		value = 400,
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_torso_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_torso.png",			
	},

	augment_net_downlink = util.extend( commondefs.augment_template )
	{
		name =STRINGS.ITEMS.AUGMENTS.NET_DOWNLINK,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.NET_DOWNLINK_TIP, 
		flavor = STRINGS.ITEMS.AUGMENTS.NET_DOWNLINK_FLAVOR, 
		keyword = "NETWORK", 
		traits =  util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			grafterWeight = 10,
			maxDownlinkMp = 6,
			bonusDownlinkMp = 1,
		},		
		value = 750, 
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_head_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_head.png",			
	},
	
	W93_augment_charged_actuators = util.extend( commondefs.augment_template )
	{
        	type = "W93_augment_shielding_rig",
		name = STRINGS.ITEMSEXTEND.AUGMENTS.CHARGED_ACTUATORS,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.CHARGED_ACTUATORS_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.CHARGED_ACTUATORS_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			grafterWeight = 10,
			ammo = 0,
			maxAmmo = 3,
			effect = "KO",
			effectValue = 1,
			skillBoost = "inventory",
			rebootTime = 8,
			skillIcon = "gui/icons/item_icons/items_icon_small/icon-augment_charged_actuator.png",
		},				
		value = 1100, 
		soldAfter = 24,
		abilities = util.tconcat( commondefs.augment_template.abilities, { "W93_console_use" }),
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-augment_charged_actuator.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-augment_charged_actuator.png",				
	},

	W93_augment_charged_crypto_hasher = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.CHARGED_CRYPTO_HASHER,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.CHARGED_CRYPTO_HASHER_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.CHARGED_CRYPTO_HASHER_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			grafterWeight = 10,
			effect = "CR",
			effectValue = 10,
			skillBoost = "anarchy",
			rebootTime = 8,
			skillIcon = "gui/icons/item_icons/items_icon_small/icon-augment_charged_crypto_hasher.png",
		},				
		value = 1100,
		soldAfter = 24,
		abilities = util.tconcat( commondefs.augment_template.abilities, { "W93_console_use" }),
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-augment_charged_crypto_hasher.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-augment_charged_crypto_hasher.png",				
	},

	W93_augment_charged_servo = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.CHARGED_SERVO,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.CHARGED_SERVO_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.CHARGED_SERVO_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			grafterWeight = 10,
			effect = "MP",
			effectValue = 6,
			skillBoost = "stealth",
			rebootTime = 8,
			skillIcon = "gui/icons/item_icons/items_icon_small/icon-augment_charged_servo_small.png",
		},				
		value = 1100,
		soldAfter = 24,
		abilities = util.tconcat( commondefs.augment_template.abilities, { "W93_console_use" }),
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-augment_charged_servo_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-augment_charged_servo.png",				
	},

	W93_augment_charged_telemeter = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.CHARGED_TELEMETER,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.CHARGED_TELEMETER_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.CHARGED_TELEMETER_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			grafterWeight = 10,
			effect = "FW",
			effectValue = 5,
			skillBoost = "hacking",
			rebootTime = 8,
			skillIcon = "gui/icons/item_icons/items_icon_small/icon-augment_charged_telemeter_small.png",
		},				
		value = 1100,
		soldAfter = 24,
		abilities = util.tconcat( commondefs.augment_template.abilities, { "W93_console_use" }),
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-augment_charged_telemeter_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-augment_charged_telemeter.png",				
	},


	W93_augment_dartKO_fabricator = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.DARTKO_FABRICATOR,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.DARTKO_FABRICATOR_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.DARTKO_FABRICATOR_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			stackable = true,
			modTrait = {{"rangedKO_bonus", 2}},
			grafterWeight = 10,	
		},				
		value = 800, 
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-augment_dartKOfabricator_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-augment_dartKOfabricator.png",				
	},

	W93_augment_dart_translocator = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.DART_TRANSLOCATOR,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.DART_TRANSLOCATOR_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.DART_TRANSLOCATOR_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			addTrait = {{"rangedKO_warpTarget", 1}},
			cooldown = 0,
			cooldownMax = 4,
			pwrCost = 3,
			grafterWeight = 10,
		},
		abilities = util.tconcat( commondefs.augment_template.abilities, { "W93_dart_translocator" }),
		value = 300,
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_torso_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_torso.png",
	},

	W93_augment_dermal_armor = util.extend( commondefs.augment_template )
	{
        	type = "W93_augment_shielding_rig",
		name = STRINGS.ITEMSEXTEND.AUGMENTS.DERMAL_ARMOR,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.DERMAL_ARMOR_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.DERMAL_ARMOR_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			stackable = true,
			modTrait = {{"woundsMax", 2}},
			addTrait = {{"hit_metal", true}},
			grafterWeight = 10,	
		},				
		value = 450, 
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-augment_dermal_armor_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-augment_dermal_armor.png",				
	},

	W93_augment_icebreak = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.MANUAL_OVERRIDE,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.MANUAL_OVERRIDE_TIP, 
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.MANUAL_OVERRIDE_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			addAbilities = "W93_manual_ice_break",
			grafterWeight = 10,			
		},
		value = 800, 	
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-augment_manual_override_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-augment_manual_override.png",		
	},

	W93_augment_hostage_monitor = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.HOSTAGE_MONITOR,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.HOSTAGE_MONITOR_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.HOSTAGE_MONITOR_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			addAbilities = "W93_hostage_monitor",
			grafterWeight = 10,			
		},		
		value = 300, 
		profile_icon = "gui/icons/skills_icons/skills_icon_small/icon-item_augment_shalem_small.png",
    		profile_icon_100 = "gui/icons/skills_icons/icon-item_augment_shalem.png",					
	},

	W93_augment_quiet_run = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.FOOTFALL_DAMPENER,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.FOOTFALL_DAMPENER_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.FOOTFALL_DAMPENER_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			modTrait = {{"dashSoundRange", -3}},
			grafterWeight = 10,			
		},		
		value = 300, 
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-augment_footfall_dampener_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-augment_footfall_dampener.png",
	},

	W93_augment_scanner_mesh = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.SCANNER_MESH,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.SCANNER_MESH_TIP, 
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.SCANNER_MESH_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			grafterWeight = 10,
			range = 5,			
		},
		value = 1600,
		soldAfter = 48,
		abilities = util.tconcat( commondefs.augment_template.abilities, { "W93_scanner_mesh" }),	
		profile_icon = "gui/icons/skills_icons/skills_icon_small/icon-item_augment_internationale_small.png",
    		profile_icon_100 = "gui/icons/skills_icons/icon-item_augment_internationale.png",	
	},

	W93_augment_shielding_rig = util.extend( commondefs.augment_template )
	{
        	type = "W93_augment_shielding_rig",
		name = STRINGS.ITEMSEXTEND.AUGMENTS.SHIELDING_RIG,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.SHIELDING_RIG_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.SHIELDING_RIG_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			modTrait = {{"shields", 0},{"shieldsMax",0}},
			addTrait = {{"neutralize_shield",0}},
			addAbilities = "W93_toggle_shield",
			pwrCost = 8,
			grafterWeight = 5,	
		},				
		value = 650,
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-augment_shielding_rig_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-augment_shielding_rig.png",				
	},

	W93_augment_subdermal_cloak = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.SUBDERMAL_CLOAK_PROJECTOR,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.SUBDERMAL_CLOAK_PROJECTOR_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.SUBDERMAL_CLOAK_PROJECTOR_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			addAbilities = "W93_useInvisiCloak",
			cooldown = 0,
			cooldownMax = 3,
			CPUperTurn=4,
			grafterWeight = 10,
			pwrCost=5,	
		},			
		value = 750, 
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_holomesh_Prism.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_holomesh_Prism.png",
	},

	W93_augment_subdermal_dart_pocket = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.SUBDERMAL_DART_POCKET,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.SUBDERMAL_DART_POCKET_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.SUBDERMAL_DART_POCKET_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			ammo = 1,
			maxAmmo = 1,
			grafterWeight = 10,
		},
		value = 1100,
		soldAfter = 24,
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-augment_dart_pocket_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-augment_dart_pocket.png",
	},

	W93_augment_subdermal_pwrbank = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.SUBDERMAL_POWER_BANK,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.SUBDERMAL_POWER_BANK_TIP, 
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.SUBDERMAL_POWER_BANK_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			addAbilities = "W93_toggle_pwrbank",
			addTrait = {{"pwr_bank", 0}},
			pwrCost = 8,
			grafterWeight = 10,			
		},
		value = 1200,
		soldAfter = 24,	
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-augment_pwrbank_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-augment_pwrbank.png",	
	},

	W93_augment_wmi = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.WMI,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.WMI_TIP, 
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.WMI_FLAVOR,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			addAbilities = "W93_wmi",
			grafterWeight = 10,
			range = 3,		
		},
		value = 800, 	
		profile_icon = "gui/icons/skills_icons/skills_icon_small/icon-item_augment_internationale_small.png",
    		profile_icon_100 = "gui/icons/skills_icons/icon-item_augment_internationale.png",	
	},
}

for id, template in pairs(augment_templates) do
	template.id = id
end

return augment_templates
