local util = include( "modules/util" )
local commondefs = include( "sim/unitdefs/commondefs" )
local simdefs = include( "sim/simdefs" )

local augment_templates = {
	augment_skill_chip_speed = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.SKILL_CHIP_SPEED,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.SKILL_CHIP_SPEED_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.SKILL_CHIP_SPEED_FLAVOR, 	
		value = 450,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			modTrait = {{"sprintBonus", 3}},
			grafterWeight = 5,
			dlcFooter = { "Contingency Plan","gui/icons/contingency_plan.png","Klei"},
		},		
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_head_small2.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_head2.png",				
	},

	augment_skill_chip_hacking = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.SKILL_CHIP_HACKING,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.SKILL_CHIP_HACKING_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.SKILL_CHIP_HACKING_FLAVOR, 	
		value = 450, 
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			modTrait = {{"hacking_bonus", 2}},
			grafterWeight = 5,
			dlcFooter = { "Contingency Plan","gui/icons/contingency_plan.png","Klei"},
		},		
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_head_small2.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_head2.png",				
	},

	augment_skill_chip_strength = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.SKILL_CHIP_STRENGTH,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.SKILL_CHIP_STRENGTH_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.SKILL_CHIP_STRENGTH_FLAVOR, 		
		value = 450,
		AUGMENT_LIST = true, 
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			grafterWeight = 5,
			applyFn = "isClosedDoor",
			cooldown = 0,
			cooldownMax = 3,
			damage = 4,
			weaponAbility = "W93_guard_kick",
			dlcFooter = { "Contingency Plan","gui/icons/contingency_plan.png","Klei"},
		},
        	abilities = util.tconcat( commondefs.augment_template.abilities, { "W93_breakDoor", "W93_guard_kick" }),	
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_head_small2.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_head2.png",				
	},

	augment_skill_chip_anarchy = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.SKILL_CHIP_ANARCHY,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.SKILL_CHIP_ANARCHY_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.SKILL_CHIP_ANARCHY_FLAVOR,
		value = 450,
		AUGMENT_LIST = true,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			modTrait = {{"apMax", 1}},
			grafterWeight = 5,
			dlcFooter = { "Contingency Plan","gui/icons/contingency_plan.png","Klei"},
		},		
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_head_small2.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_head2.png",				
	},

	augment_gel_injectors = util.extend( commondefs.augment_template )
	{
		name = STRINGS.DLC1.GEL_INJECTORS,
		desc = string.format(STRINGS.ITEMSEXTEND.AUGMENTS.GEL_INJECTORS_TIP, simdefs.TRACKER_MAXSTAGE/2),
		flavor = STRINGS.DLC1.GEL_INJECTORS_FLAVOR, 	

		AUGMENT_LIST = true,

		value = 1200, 
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			modTrait = {{"mpMax", simdefs.TRACKER_MAXSTAGE/2}},		
			alarmMPmod = -0.5,
			alarmMPmodTxt = STRINGS.DLC1.GEL_INJECTORS,
			grafterWeight = 10,
			dlcFooter = { "Contingency Plan","gui/icons/contingency_plan.png","Klei"},
		},		
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_leg_small2.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_leg2.png",				
	},

	augment_reactive_moyomer = util.extend( commondefs.augment_template )
	{
		name = STRINGS.DLC1.REACTIVE_MOYOMER,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.REACTIVE_MOYOMER_TIP,
		flavor = STRINGS.DLC1.REACTIVE_MOYOMER_FLAVOR, 	

		AUGMENT_LIST = true,

		value = 800, 
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){		
			alarmMPmod = 0.5,
			alarmMPmodTxt = STRINGS.DLC1.REACTIVE_MOYOMER,
			grafterWeight = 10,
			dlcFooter = { "Contingency Plan","gui/icons/contingency_plan.png","Klei"},
		},		
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_leg_small2.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_leg2.png",				
	},

	augment_pheromone_filter = util.extend( commondefs.augment_template )
	{
		name = STRINGS.DLC1.PHEROMONE_FILTER,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.PHEROMONE_FILTER_TIP,
		flavor = STRINGS.DLC1.PHEROMONE_FILTER_FLAVOR, 		
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){ 
			boost_AP_on_wakeup = 3,
			boost_AP_on_wakeup_txt =  STRINGS.DLC1.PHEROMONE_FILTER,
			grafterWeight = 10,
			dlcFooter = { "Contingency Plan","gui/icons/contingency_plan.png","Klei"},
		},
		AUGMENT_LIST = true,

		value = 550, 
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_head_small2.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_head2.png",				
	},
}

return augment_templates