local array = include( "modules/array" )
local util = include( "modules/util" )
local commondefs = include( "sim/unitdefs/commondefs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )

local item_templates =
{
	item_stim = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.STIM_BURST,
		desc = STRINGS.ITEMSEXTEND.ITEMS.STIM_BURST_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.STIM_BURST_FLAVOR,
		icon = "itemrigs/FloorProp_Bandages.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_stim_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_stim.png",
		traits = { cooldown = 0, cooldownMax = 4, mpRestored = 4 },
		requirements = {},
		abilities = { "carryable","recharge","use_stim" },
		value = 800,
		floorWeight = 2, 
	},

	item_stim_2 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.STIM,
		desc = STRINGS.ITEMSEXTEND.ITEMS.STIM_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.STIM_FLAVOR,
		icon = "itemrigs/FloorProp_Bandages.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_stim_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_stim.png",
		traits = { cooldown = 0, cooldownMax = 7, mpRestored = 8 },
		requirements = {},
		abilities = { "carryable","recharge","use_stim" },
		value = 750,
		floorWeight = 2, 
	},

	item_stim_3 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.STIM_COMBAT,
		desc = STRINGS.ITEMSEXTEND.ITEMS.STIM_COMBAT_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.STIM_COMBAT_FLAVOR,
		icon = "itemrigs/FloorProp_Bandages.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_combat_stim_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_combat_stim.png",
		traits = { cooldown = 0, cooldownMax = 4, ap = 1, mpRestored = 0 },
		requirements = {},
		abilities = { "carryable","recharge","use_stim" },
		value = 300,
		floorWeight = 2,
	},

	item_paralyzer = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER,
		desc = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_paralyzerdose_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_paralyzer_dose.png",	
		abilities = { "carryable","recharge","paralyze" },
		requirements = { anarchy = 2 },
		traits = { cooldown = 0, cooldownMax = 5, koTime = 2 },
		value = 400,
		floorWeight = 2,
	},

	item_paralyzer_2 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_CONCENTRATED,
		desc = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_CONCENTRATED_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_CONCENTRATED_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_paralyzerdose_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_paralyzer_dose.png",	
		abilities = { "carryable","recharge","paralyze" },
		requirements = { anarchy = 2 },
		traits = { cooldown = 0, cooldownMax = 11, koTime = 6 },
		value = 800,
		floorWeight = 3,
	},

	item_paralyzer_3 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_BLIND,
		desc = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_BLIND_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_BLIND_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_mindwipesyringe_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_mindwipesyringe.png",	
		abilities = { "carryable","recharge","paralyze" },
		requirements = { anarchy = 2 },
		traits = { cooldown = 0, cooldownMax = 8, koTime = 2, impare_sight = 2 },
		value = 600,
		floorWeight = 2,
	},

	item_laptop = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_SERVER_SIPHON,
		desc = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_SERVER_SIPHON_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_SERVER_SIPHON_FLAVOR,
		icon = "console.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_laptop_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_laptop.png",
		kanim = "kanim_laptop",
		traits = { laptop=true, mainframe_icon_on_deploy=true, mainframe_status = "active", sightable = true, cpus = 2, maxcpus = 2, cpuTurn = 1, cpuTurnMax = 1, hidesInCover = true, cooldown = 0, cooldownMax = 2, alarmCPUfinite = true },
		requirements = { hacking = 2 },
		abilities = {"deployable", "alarmCPU", "carryable"},
		sounds = {spot="SpySociety/Objects/computer_types", deploy="SpySociety/Objects/SuitcaseComputer_open",pickUp="SpySociety/Objects/SuitcaseComputer_close"},
		rig = "consolerig",
		value = 1250,
		floorWeight = 2,
		soldAfter = 24,
		locator = true,
	},

	item_laptop_2 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_SERVER,
		desc = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_SERVER_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_SERVER_FLAVOR,
		icon = "console.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_laptop_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_laptop.png",
		kanim = "kanim_laptop",
		traits = { laptop=true, mainframe_icon_on_deploy=true, mainframe_status = "active", sightable = true, cpus = 1, maxcpus = 1, cpuTurn = 1, cpuTurnMax = 1, hidesInCover = true, cooldown = 0, cooldownMax = 3 },
		requirements = { hacking = 2 },
		abilities = {"deployable", "generateCPU", "carryable"},
		sounds = {spot="SpySociety/Objects/computer_types", deploy="SpySociety/Objects/SuitcaseComputer_open",pickUp="SpySociety/Objects/SuitcaseComputer_close"},
		rig = "consolerig",
		value = 1500,
		floorWeight = 3,
		soldAfter = 48,
		locator = true,
	},

	item_laptop_3 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_SERVER_SPIKE,
		desc = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_SERVER_SPIKE_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_SERVER_SPIKE_FLAVOR,
		icon = "console.png",		
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_laptop_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_laptop.png",
		kanim = "kanim_laptop",
		traits = { laptop=true, mainframe_icon_on_deploy=true, mainframe_status = "active", sightable = true, cpus = 7, maxcpus = 7, cpuTurn = 1, cpuTurnMax = 4, hidesInCover = true,  cooldown = 3, cooldownMax = 5 },
		requirements = { hacking = 2 },
		abilities = {"deployable", "generateCPU", "carryable"},
		sounds = {spot="SpySociety/Objects/computer_types", deploy="SpySociety/Objects/SuitcaseComputer_open",pickUp="SpySociety/Objects/SuitcaseComputer_close"},
		rig = "consolerig",
		value = 2000,
		floorWeight = 4,
		soldAfter = 72,
		locator = true,
	},

	item_cloakingrig_1 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_FLICKER,
		desc = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_FLICKER_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_FLICKER_FLAVOR,
		icon = "itemrigs/FloorProp_InvisiCloakTimed.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_invisicloak_small.png",			
		profile_icon_100 = "gui/icons/item_icons/icon-item_invisi_cloak.png",
		traits = { duration = 1, cooldown = 0, cooldownMax = 9,  cloakDistanceMax=7, cloakInVision = false },
		requirements = { stealth = 2 },
		abilities = { "carryable","recharge","useInvisiCloak" },
		value = 650,
		floorWeight = 2, 
	},

	item_cloakingrig_2 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.CLOAK,
		desc = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_FLAVOR,
		icon = "itemrigs/FloorProp_InvisiCloakTimed.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_invisicloak_small.png",			
		profile_icon_100 = "gui/icons/item_icons/icon-item_invisi_cloak.png",
		traits = { duration = 1, cooldown = 0, cooldownMax = 14, cloakInVision = true },
		requirements = { stealth = 2 },
		abilities = { "carryable","recharge","useInvisiCloak" },
		value = 1100,
		floorWeight = 3,
		soldAfter = 24,
	},

	item_cloakingrig_3 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_CHAMELEON,
		desc = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_CHAMELEON_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_CHAMELEON_FLAVOR,
		icon = "itemrigs/FloorProp_InvisiCloakTimed.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_invisicloak_small.png",			
		profile_icon_100 = "gui/icons/item_icons/icon-item_invisi_cloak.png",
		traits = { duration = 3, cooldown = 0, cooldownMax = 18, cloakDistanceMax=9, cloakInVision = true },
		requirements = { stealth = 2 },
		abilities = { "carryable","recharge","useInvisiCloak" },
		value = 800,
		floorWeight = 3,
	},

	item_cloakingrig_3_17_5 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_CHAMELEON,
		desc = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_CHAMELEON_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_CHAMELEON_FLAVOR,
		icon = "itemrigs/FloorProp_InvisiCloakTimed.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_invisicloak_small.png",			
		profile_icon_100 = "gui/icons/item_icons/icon-item_invisi_cloak.png",
		traits = { duration = 3, cooldown = 0, cooldownMax = 18, cloakDistanceMax=9, cloakInVision = true },
		requirements = { stealth = 2 },
		abilities = { "carryable","recharge","useInvisiCloak" },
		value = 800,
		floorWeight = 3,
	},

	item_icebreaker= util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.BUSTER,
		desc = STRINGS.ITEMSEXTEND.ITEMS.BUSTER_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.BUSTER_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",		
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_chip_hyper_buster_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_chip_ice_breaker.png",		
		traits = { icebreak = 2, cooldown = 0, cooldownMax = 3 },
		requirements = { anarchy = 2, },
		abilities = { "icebreak","recharge","carryable" },
		value = 400,
		floorWeight = 2,
	},

	item_icebreaker_2 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.BUSTER_PRECISE,
		desc = STRINGS.ITEMSEXTEND.ITEMS.BUSTER_PRECISE_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.BUSTER_PRECISE_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",		
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_chip_hyper_buster_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_chip_ice_breaker.png",		
		traits = { icebreak = 1, usesCharges=true, charges=12, chargesMax=12 },
		requirements = { anarchy = 2, },
		abilities = { "icebreak","recharge","carryable" },
		value = 600,
		floorWeight = 3,
	},

	item_icebreaker_3 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.BUSTER_BRUTE,
		desc = STRINGS.ITEMSEXTEND.ITEMS.BUSTER_BRUTE_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.BUSTER_BRUTE_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",		
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_chip_hyper_buster_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_chip_ice_breaker.png",		
		traits = { icebreak = 8, cooldown = 0, cooldownMax = 7 },
		requirements = { anarchy = 2, },
		abilities = { "icebreak","recharge","carryable" },
		value = 500,
		floorWeight = 3,
	},

	item_portabledrive = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_DRIVE,
		desc = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_DRIVE_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_DRIVE_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_chip_accellerator_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_chip_accellerator.png",	
		traits = { hacking_bonus = 2,  cooldown = 0, cooldownMax = 2, reprimeTime = 2, reprimePWR = 1 },
		requirements = { anarchy = 2, },
		abilities = { "carryable","recharge","jackin","W93_reprime" },
		value = 400,
		floorWeight = 2,
	},

	item_portabledrive_2 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_DRIVE_BOOST,
		desc = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_DRIVE_BOOST_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_DRIVE_BOOST_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_chip_accellerator_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_chip_accellerator.png",	
		traits = { hacking_bonus = 4, usesCharges=true, charges=4, chargesMax=4, reprimeTime = 4, reprimePWR = 4  },
		requirements = { anarchy = 2, },
		abilities = { "carryable","recharge","jackin","W93_reprime" },
		value = 500,
		floorWeight = 2,
	},

	item_portabledrive_3 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_DRIVE_BRUTE,
		desc = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_DRIVE_BRUTE_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_DRIVE_BRUTE_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_chip_accellerator_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_chip_accellerator.png",	
		traits = { hacking_bonus = 12,  cooldown = 0, cooldownMax = 8, reprimeTime = 6, reprimePWR = 10 },
		requirements = { anarchy = 2, },
		abilities = { "carryable","recharge","jackin","W93_reprime" },
		value = 600,
		floorWeight = 3,
	},

	item_shocktrap = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP,
		desc = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_shocktrap_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_shock trap.png",		
		traits = { cooldown = 0, cooldownMax = 8, damage = 4, stun = 4, ignoreArmor = false, armorPiercing = 4, soundRange = 4, applyFn = "isClosedDoor", doorDevice = "simtrap" },
		requirements = { anarchy = 3 },
		abilities = { "doorMechanism","recharge", "carryable" },
		value = 700,
		floorWeight = 2,
	},

	item_shocktrap_2 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_CON,
		desc = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_CON_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_CON_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_shocktrap_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_shock trap.png",		
		traits = { cooldown = 0, cooldownMax = 10, damage = 3, stun = 3, ignoreArmor = true, soundRange = 4, applyFn = "isClosedDoor", doorDevice = "simtrap" },
		requirements = { anarchy = 3 },
		abilities = { "doorMechanism","recharge","carryable" },
		value = 750,
		floorWeight = 2,
	},

	item_shocktrap_3 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_OVR,
		desc = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_OVR_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_OVR_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_shocktrap_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_shock trap.png",		
		traits = { cooldown = 0, cooldownMax = 14, damage = 8, stun = 8, ignoreArmor = false, armorPiercing = 2, soundRange = 4, applyFn = "isClosedDoor", doorDevice = "simtrap" },
		requirements = { anarchy = 3 },
		abilities = { "doorMechanism","recharge","carryable" },
		value = 800,
		floorWeight = 3,
	},

	item_shocktrap_3_17_9 = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_PACK,
		desc = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_PACK_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_PACK_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_shocktrap_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_shock trap.png",		
		traits = {usesCharges=true, charges = 4, chargesMax = 4, damage = 3, stun = 3, range = 2, ignoreArmor = false, armorPiercing = 1, friendlyFire = true, soundRange = 4, applyFn = "isClosedDoor", doorDevice = "simtrap" },
		requirements = { anarchy = 3 },
		abilities = { "doorMechanism","recharge","carryable" },
		value = 750,
		floorWeight = 2,
	},

	item_emp_pack = util.extend(commondefs.item_template)
	{
		type = "simemppack",
		name = STRINGS.ITEMSEXTEND.ITEMS.EMP,
		desc = STRINGS.ITEMSEXTEND.ITEMS.EMP_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.EMP_FLAVOR,
		icon = "itemrigs/FloorProp_emp.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_emp_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_emp.png",	
		abilities = { "carryable","recharge","prime_emp", },
		requirements = { hacking = 2 },
		traits = { cooldown = 0, cooldownMax = 4, soundRange = 4, range = 4, emp_duration = 2 },
		value = 700,
		floorWeight = 2,
	},

	item_emp_pack_2 = util.extend(commondefs.item_template)
	{
		type = "simemppack",
		name = STRINGS.ITEMSEXTEND.ITEMS.EMP_OVR,
		desc = STRINGS.ITEMSEXTEND.ITEMS.EMP_OVR_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.EMP_OVR_FLAVOR,
		icon = "itemrigs/FloorProp_emp.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_emp_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_emp.png",	
		abilities = { "carryable","recharge","prime_emp", },
		requirements = { hacking = 2 },
		traits = { cooldown = 0, cooldownMax = 12, soundRange = 3, range = 2, emp_duration = 6 },
		value = 600,
		floorWeight = 2,
	},

	item_emp_pack_3 = util.extend(commondefs.item_template)
	{
		type = "simemppack",
		name = STRINGS.ITEMSEXTEND.ITEMS.EMP_AMP,
		desc = STRINGS.ITEMSEXTEND.ITEMS.EMP_AMP_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.EMP_AMP_FLAVOR,
		icon = "itemrigs/FloorProp_emp.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_emp_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_emp.png",	
		abilities = { "carryable","recharge","prime_emp", },
		requirements = { hacking = 2 },
		traits = { usesCharges=true, charges=6, chargesMax=6, soundRange = 2, range = 1, emp_duration = 3 },
		value = 600,
		floorWeight = 2,
	},

	item_stickycam = util.extend( commondefs.grenade_template )
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.GRENADE_CAMERA,
		desc = STRINGS.ITEMSEXTEND.ITEMS.GRENADE_CAMERA_TOOLTIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.GRENADE_CAMERA_FLAVOR,
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_Sticky_Cam_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_Sticky_Cam.png",
		kanim = "kanim_stickycam",		
		sounds = {activate="SpySociety/Grenades/stickycam_deploy", bounce="SpySociety/Grenades/bounce"},
		traits = { camera=true, LOSarc = math.pi * 2, disposable=false, agent_filter=true, throwUnit="W93_item_stickycam", usesCharges=true, charges=2, chargesMax=2 },
		abilities = { "carryable", "recharge", "throw" },
		value = 400,
		floorWeight = 2, 
		locator=true,
	},

	item_lockdecoder = util.extend( commondefs.item_template )
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.LOCK_DECODER,
		desc = STRINGS.ITEMSEXTEND.ITEMS.LOCK_DECODER_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.LOCK_DECODER_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_lock_decoder_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_lock_decoder.png",		
		traits = { disposable = false, usesCharges = true, charges = 1, chargesMax = 1, decodeVault = true, applyFn = "isClosedDoor", profile_icon="gui/icons/item_icons/items_icon_small/icon-item_lock_decoder_small.png" },
		requirements = { anarchy = 3 },
		abilities = { "doorMechanism", "carryable" },
		value = 450,		
		floorWeight = 2,
	},

	item_smokegrenade = util.extend( commondefs.grenade_template )
	{
        	type = "smoke_grenade",
		name = STRINGS.ITEMS.GRENADE_SMOKE,
		desc = STRINGS.ITEMS.GRENADE_SMOKE_TOOLTIP,
		flavor = STRINGS.ITEMS.GRENADE_SMOKE_FLAVOR,
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_smoke_grenade_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_smoke_grenade.png",	
		kanim = "kanim_stickycam",		
		sounds = {explode="SpySociety/Grenades/smokegrenade_explo", bounce="SpySociety/Grenades/bounce_smokegrenade"},
		abilities = { "carryable", "reload", "throw" },
		traits = { throwUnit="W93_item_smokegrenade", range=3, disposable = false, ammo=1, maxAmmo=1 },
		value = 300,
		floorWeight = 2, 
		locator=true,

		createUpgradeParams = function( self, unit )
        		local params = { traits = { ammo = 0, } }
			params.traits.ammo = unit:getTraits().ammo
        		return params
		end,
	},

	item_wireless_scanner_custom = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMS.WIRELESS_SCANNER_CUSTOM, 
		desc = STRINGS.ITEMS.WIRELESS_SCANNER_TOOLTIP, 
        	flavor = STRINGS.ITEMS.WIRELESS_SCANNER_FLAVOR,
		icon = "itemrigs/FloorProp_MotionDetector.png", 
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_scanner_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_scanner.png",
		requirements = { hacking = 2 },		
		abilities = { "carryable", "wireless_scan" },
		value = 600,
		traits = { wireless_range = 5 },
	},

	W93_item_hyper_cell = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.HYPER_CELL,
		desc = STRINGS.ITEMSEXTEND.ITEMS.HYPER_CELL_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.HYPER_CELL_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_magazine_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_magazine.png",	
		ITEM_LIST = true,									
		traits = { ammo_clip = 3, ammo = 3, maxAmmo = 3, fullRecharge = true, overRecharge = true },
		abilities = { "carryable" },
		value = 1200,
		floorWeight = 4,
		soldAfter = 48,

		createUpgradeParams = function( self, unit )
        		local params = { traits = { ammo = 0, } }
			params.traits.ammo = unit:getTraits().ammo
        		return params
		end,
	},

	W93_item_charge_cell = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.CHARGE_CELL,
		desc = STRINGS.ITEMSEXTEND.ITEMS.CHARGE_CELL_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.CHARGE_CELL_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_magazine_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_magazine.png",	
		ITEM_LIST = true,									
		traits = { ammo_clip = 1, ammo = 1, maxAmmo = 1, fullRecharge = true, disposable = false },
		abilities = { "carryable" },
		value = 1600,
		floorWeight = 4,
		soldAfter = 48,

		createUpgradeParams = function( self, unit )
        		local params = { traits = { ammo = 0, ammo_clip = 0 } }
			params.traits.ammo = unit:getTraits().maxAmmo
			params.traits.ammo_clip = unit:getTraits().maxAmmo
        		return params
		end,
	},
	
	W93_item_stim_military = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.STIM_MILITARY,
		desc = STRINGS.ITEMSEXTEND.ITEMS.STIM_MILITARY_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.STIM_MILITARY_FLAVOR,
		icon = "itemrigs/FloorProp_Bandages.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_combat_stim_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_combat_stim.png",
		ITEM_LIST = true,
		traits = { cooldown = 0, cooldownMax = 8, ap = 3, mpRestored = 0 },
		requirements = {},
		abilities = { "carryable","recharge","use_stim" },
		value = 500,
		floorWeight = 3,
	},

	W93_item_laptop_cryptography = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_SERVER_CRYPTOGRAPHY,
		desc = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_SERVER_CRYPTOGRAPHY_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.PORTABLE_SERVER_CRYPTOGRAPHY_FLAVOR,
		icon = "console.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_laptop1_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_laptop1.png",
		kanim = "kanim_laptop",
		ITEM_LIST = true,
		traits = { laptop=true, mainframe_icon_on_deploy=true, mainframe_status = "active", sightable = true, alarmDecrease = 1, cpus = 0, cpuTurn = 1, cpuTurnMax = 6, hidesInCover = true, cooldown = 0, cooldownMax = 3 },
		requirements = { hacking = 4 },
		abilities = {"deployable", "W93_alarmServer", "carryable"},
		sounds = { deploy="SpySociety/Objects/SuitcaseComputer_open",pickUp="SpySociety/Objects/SuitcaseComputer_close"},
		rig = "consolerig",
		value = 2500,
		floorWeight = 4,
		soldAfter = 72,
		locator = true,
	},

	W93_item_scan_pack = util.extend(commondefs.item_template)
	{
		type = "simemppack",
		name = STRINGS.ITEMSEXTEND.ITEMS.SCAN_PACK,
		desc = STRINGS.ITEMSEXTEND.ITEMS.SCAN_PACK_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.SCAN_PACK_FLAVOR,
		icon = "itemrigs/FloorProp_emp.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_scan_pack_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_scan_pack.png",	
		abilities = { "carryable","recharge","prime_emp", },
		traits = { cooldown = 0, cooldownMax = 2, range = 7, soundRange = 2, scan_pack = true, usesCharges=true, charges=5, chargesMax=5 },
		value = 150,
		floorWeight = 2,
		ITEM_LIST = true,
	},

	W93_item_stickycam = util.extend( commondefs.npc_grenade_template )
	{
		name = STRINGS.ITEMS.GRENADE_CAMERA,
		desc = STRINGS.ITEMS.GRENADE_CAMERA_TOOLTIP,
		flavor = STRINGS.ITEMS.GRENADE_CAMERA_FLAVOR,
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_Sticky_Cam_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_Sticky_Cam.png",
		kanim = "kanim_stickycam",		
		sounds = {activate="SpySociety/Grenades/stickycam_deploy", bounce="SpySociety/Grenades/bounce"},
		traits = { camera=true, LOSarc = math.pi * 2, disposable=true, agent_filter=true, throwUnit="W93_item_stickycam", usesCharges=true, charges=3, chargesMax=3 },
		abilities = {},
		value = 1,
		locator=true,
	},

	W93_item_drone_toolkit = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.DRONE_TOOLKIT,
		desc = STRINGS.ITEMSEXTEND.ITEMS.DRONE_TOOLKIT_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.DRONE_TOOLKIT_FLAVOR,
		icon = "console.png",
		profile_icon = "gui/icons/skills_icons/skills_icon_small/icon-item_technician_small.png",
		profile_icon_100 = "gui/icons/skills_icons/icon-skill_technician.png",	
		abilities = { "carryable","recharge","W93_drone_toolkit_AP","W93_drone_toolkit_scanner","W93_drone_toolkit_firewall" },
		requirements = { hacking = 3 },
		traits = { cooldown = 0, cooldownMax = 4, usesCharges=true, charges=2, chargesMax=2, reduceAP = 3, reduceFirewall = 4 },
		value = 800,
		floorWeight = 3,
		ITEM_LIST = true,
	},

	W93_item_door_controller = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.DOOR_CONTROLLER,
		desc = STRINGS.ITEMSEXTEND.ITEMS.DOOR_CONTROLLER_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.DOOR_CONTROLLER_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_door_controller_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_door_controller.png",		
		abilities = { "carryable", "recharge", "W93_doorControllerUse" },
		requirements = {},		
		traits = { cooldown = 0, cooldownMax = 3, range = 7, W93_DoorAugment = true },
		value = 400,
		floorWeight = 2,
		ITEM_LIST = true,	
	},

	W93_item_neural_data_extractor = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.NEURAL_DATA_EXTRACTOR,
		desc = STRINGS.ITEMSEXTEND.ITEMS.NEURAL_DATA_EXTRACTOR_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.NEURAL_DATA_EXTRACTOR_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_neural_data_extractor_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_neural_data_extractor.png",
		abilities = { "carryable", "recharge", "W93_neural_data_extract" },
		traits = { cooldown = 0, cooldownMax = 3, crExtractMin = 300, crExtractMax = 500 },
		requirements = { hacking = 2 },
		value = 400,
		floorWeight = 2,
		ITEM_LIST = true,
	},

	W93_item_smokegrenade = util.extend( commondefs.grenade_template )
	{
        	type = "smoke_grenade",
		name = STRINGS.ITEMS.GRENADE_SMOKE,
		desc = STRINGS.ITEMS.GRENADE_SMOKE_TOOLTIP,
		flavor = STRINGS.ITEMS.GRENADE_SMOKE_FLAVOR,
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_smoke_grenade_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_smoke_grenade.png",	
		kanim = "kanim_stickycam",		
		sounds = {explode="SpySociety/Grenades/smokegrenade_explo", bounce="SpySociety/Grenades/bounce_smokegrenade"},
		abilities = { "carryable", "recharge", "throw" },
		traits = { on_spawn = "smoke_cloud", range=3, noghost = true, explodes = 0 }, 
		locator=true,
	},

	W93_item_paralyzer_neural = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_NEURAL,
		desc = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_NEURAL_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_NEURAL_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_paralyzerdose_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_paralyzer_dose.png",	
		abilities = { "carryable","recharge","paralyze", "W93_paralyze" },
		requirements = { anarchy = 2 },
		traits = { cooldown = 0, cooldownMax = 8, koTime = 2 },
		value = 600,
		floorWeight = 2,
		ITEM_LIST = true,
	},

	W93_item_paralyzer_dart = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_DART,
		desc = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_DART_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_DART_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_paralyzerdose_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_paralyzer_dose.png",	
		abilities = { "carryable","recharge","paralyze" },
		requirements = { anarchy = 2 },
		traits = { cooldown = 0, cooldownMax = 8, koTime = 2, koTimeDart = 4 },
		value = 650,
		floorWeight = 2,
		ITEM_LIST = true,
	},

	W93_item_wireless_scanner = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMS.WIRELESS_SCANNER, 
		desc = STRINGS.ITEMS.WIRELESS_SCANNER_TOOLTIP, 
        	flavor = STRINGS.ITEMS.WIRELESS_SCANNER_FLAVOR,
		icon = "itemrigs/FloorProp_MotionDetector.png", 
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_scanner_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_scanner.png",
		requirements = { hacking = 3 },
		abilities = { "carryable", "wireless_scan" },
		value = 600,
		traits = { wireless_range = 4, range = 4 },
		floorWeight = 2,
		ITEM_LIST = true,
	},

	W93_item_breaching_charges = util.extend(commondefs.item_template)
	{
		type = "simemppack",
		name = STRINGS.ITEMSEXTEND.ITEMS.BREACHING_CHARGES,
		desc = STRINGS.ITEMSEXTEND.ITEMS.BREACHING_CHARGES_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.BREACHING_CHARGES_FLAVOR,
		icon = "itemrigs/FloorProp_emp.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_breaching_charges_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_breaching_charges.png",		
		abilities = { "carryable", "recharge", "prime_emp" },
		requirements = { anarchy = 3 },		
		traits = { range = 2, soundRange = 16, usesCharges = true, charges = 2, chargesMax = 2, breaching_charges = true },
		value = 1500,
		floorWeight = 4,
		soldAfter = 48,
		ITEM_LIST = true,	
	},

	W93_item_kill_trap = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.KILL_TRAP,
		desc = STRINGS.ITEMSEXTEND.ITEMS.KILL_TRAP_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.KILL_TRAP_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_killtrap_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_killtrap.png",		
		traits = { usesCharges = true, charges = 2, chargesMax = 2, ignoreArmor = false, armorPiercing = 3, stun = 1, lethal = true, friendlyFire = true, soundRange = 4, applyFn = "isClosedDoor", doorDevice = "simtrap" },
		abilities = { "doorMechanism", "recharge", "carryable" },
		requirements = { anarchy = 3 },
		value = 1000,
		floorWeight = 3,
		soldAfter = 24,
		ITEM_LIST = true,
	},

	W93_item_kill_trap_piercing = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.KILL_TRAP_PIERCING,
		desc = STRINGS.ITEMSEXTEND.ITEMS.KILL_TRAP_PIERCING_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.KILL_TRAP_PIERCING_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_killtrap_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_killtrap.png",		
		traits = { ammo = 4, maxAmmo = 4, ignoreArmor = true, stun = 1, lethal = true, friendlyFire = true, soundRange = 4, applyFn = "isClosedDoor", doorDevice = "simtrap" },
		abilities = { "doorMechanism", "carryable" },
		requirements = { anarchy = 3 },
		value = 1100,
		floorWeight = 3,
		soldAfter = 24,
		ITEM_LIST = true,

		createUpgradeParams = function( self, unit )
        		local params = { traits = { ammo = 0, } }
			params.traits.ammo = unit:getTraits().ammo
        		return params
		end,
	},

	W93_item_kill_trap_ionized = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.KILL_TRAP_IONIZED,
		desc = STRINGS.ITEMSEXTEND.ITEMS.KILL_TRAP_IONIZED_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.KILL_TRAP_IONIZED_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_killtrap_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_killtrap.png",		
		traits = { usesCharges = true, charges = 1, chargesMax = 1, ignoreArmor = false, armorPiercing = 1, range = 4, stun = 1, lethal = true, friendlyFire = true, soundRange = 4, applyFn = "isClosedDoor", doorDevice = "simtrap" },
		abilities = { "doorMechanism", "recharge", "carryable" },
		requirements = { anarchy = 3 },
		value = 1200,
		floorWeight = 3,
		soldAfter = 24,
		ITEM_LIST = true,
	},

	W93_item_kill_trap_kit = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.KILL_TRAP_KIT,
		desc = STRINGS.ITEMSEXTEND.ITEMS.KILL_TRAP_KIT_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.KILL_TRAP_KIT_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_killtrap_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_killtrap.png",		
		traits = { cooldown = 0, cooldownMax = 12, ignoreArmor = false, armorPiercing = 2, stun = 1, lethal = true, friendlyFire = true, soundRange = 4, applyFn = "isClosedDoor", doorDevice = "simtrap" },
		abilities = { "doorMechanism", "recharge", "carryable" },
		requirements = { anarchy = 3 },
		value = 1100,
		floorWeight = 3,
		soldAfter = 24,
		ITEM_LIST = true,
	},
}

ai_item_templates =
{
	item_scanchip = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMS.SCAN_CHIP,
		desc = STRINGS.ITEMSEXTEND.ITEMS.SCAN_CHIP_TIP,
		flavor = STRINGS.ITEMS.SCAN_CHIP_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_chip_daemonscan_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_chip_daemonscan.png",	
		traits = { cooldown = 0, cooldownMax = 2, PWR_conversion = 50 },
		requirements = { stealth = 2, },
		abilities = { "carryable","recharge","scandevice", "W93_ai_scan" },
		value = 100,
		floorWeight = 1,
		ITEM_LIST = true,
	},

	W93_augment_crypto_miner = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMSEXTEND.AUGMENTS.CRYPTO_MINER,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.CRYPTO_MINER_TIP, 
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.CRYPTO_MINER_FLAVOR,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			addAbilities = "W93_crypto_miner",
			grafterWeight = 10,	
			stackable = true,
		},
		value = 600, 	
		profile_icon = "gui/icons/skills_icons/skills_icon_small/icon-item_augment_internationale_small.png",
    		profile_icon_100 = "gui/icons/skills_icons/icon-item_augment_internationale.png",
		AUGMENT_LIST = true,
	},

	W93_item_hash_chip = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.HASH_CHIP,
		desc = STRINGS.ITEMSEXTEND.ITEMS.HASH_CHIP_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.HASH_CHIP_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_neural_data_extractor_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_neural_data_extractor.png",	
		traits = { hash_bonus = 1, cooldown = 0, cooldownMax = 4, },
		requirements = { hacking = 2 },
		abilities = { "carryable", "recharge", "W93_combatAI_gainHash", "W93_combatAI_gainHashHeavy" },
		value = 500,
		floorWeight = 1,
		ITEM_LIST = true,
	},

	W93_item_hash_chip_fast = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.FAST_HASH_CHIP,
		desc = STRINGS.ITEMSEXTEND.ITEMS.FAST_HASH_CHIP_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.FAST_HASH_CHIP_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_neural_data_extractor_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_neural_data_extractor.png",	
		traits = { hash_bonus = 1, usesCharges = true, charges = 6, chargesMax = 6, },
		requirements = { hacking = 2 },
		abilities = { "carryable", "recharge", "W93_combatAI_gainHash" },
		value = 550,
		floorWeight = 2,
		ITEM_LIST = true,
	},

	W93_item_hash_chip_heavy = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.HEAVY_HASH_CHIP,
		desc = STRINGS.ITEMSEXTEND.ITEMS.HEAVY_HASH_CHIP_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.HEAVY_HASH_CHIP_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_neural_data_extractor_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_neural_data_extractor.png",	
		traits = { hash_bonus = 4, cooldown = 0, cooldownMax = 6, },
		requirements = { hacking = 3 },
		abilities = { "carryable", "recharge", "W93_combatAI_gainHashHeavy" },
		value = 600,
		floorWeight = 3,
		ITEM_LIST = true,
	},
}

return {
	item_templates = item_templates,
	ai_item_templates = ai_item_templates,
}
