local util = include( "modules/util" )
local skillNames = { "stealth", "hacking", "inventory", "anarchy", "marksman" }
local skillCostsVanilla =
{
	["stealth"] = { 0, 500, 600, 700, 1000 },
	["hacking"] = { 0, 500, 600, 700, 1000 },
	["inventory"] = { 0, 300, 500, 500, 900 },
	["anarchy"] = { 0, 400, 500, 600, 800 },
	["marksman"] = { 0, 400, 600, 800, 1000 }
}
local skillCostsFlavorful =
{
	["stealth"] = { 0, 700, 550, 650, 900 },
	["hacking"] = { 0, 700, 550, 650, 900 },
	["inventory"] = { 0, 700, 550, 650, 900 },
	["anarchy"] = { 0, 700, 550, 650, 900 },
	["marksman"] = { 0, 400, 600, 800, 1000 }
}

local function earlyInit( modApi )
	modApi.requirements = { "Contingency Plan", "Interactive Events", "Function Library", "Marksmanship Skill" }
end

local function init( modApi )
	rawset(_G,"SCRIPT_PATHS",rawget(_G,"SCRIPT_PATHS") or {})
	local dataPath = modApi:getDataPath()
	KLEIResourceMgr.MountPackage( dataPath .. "/gui.kwad", "data" )

	if not SCRIPT_PATHS.W93_FuncLibActive or SCRIPT_PATHS.W93_FuncLibActive == false then
		log:write("Function Library disabled or missing! New Items and Augments is disabled.")
		return
	end

	modApi:addGenerationOption("enable_augments", STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_AUGMENTS, STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_AUGMENTS_TIP,{noUpdate = true})
	modApi:addGenerationOption("enable_items", STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_ITEMS, STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_ITEMS_TIP,{noUpdate = true})
	modApi:addGenerationOption("enable_weapons", STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_WEAPONS, STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_WEAPONS_TIP,{noUpdate = true})
	modApi:addGenerationOption("enable_rebalance", STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_REBALANCE, STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_REBALANCE_TIP,{noUpdate = true})
	modApi:addGenerationOption("enable_guard_loot", STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_LOOT, STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_LOOT_TIP,{noUpdate = true, value = 3, values = {0, 1, 2, 3}, strings={STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_LOOT_0, STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_LOOT_1, STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_LOOT_2, STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_LOOT_3}})
	modApi:addGenerationOption("endless_balance", STRINGS.ITEMSEXTEND.OPTIONS.ENDLESS_BALANCE, STRINGS.ITEMSEXTEND.OPTIONS.ENDLESS_BALANCE_TIP,{noUpdate = true, value = 0, values = {0, 1, 1.25, 1.5, 1.75, 2, -1, -1.25, -1.5, -1.75, -2},  difficulties={{1,0},{2,0},{3,0},{4,0},{5,-1.5},{6,-1.5},{7,0},{8,0}}, 
		strings={STRINGS.ITEMSEXTEND.OPTIONS.ENDLESS_BALANCE_DISABLED, STRINGS.ITEMSEXTEND.OPTIONS.ENDLESS_BALANCE_1, STRINGS.ITEMSEXTEND.OPTIONS.ENDLESS_BALANCE_2, STRINGS.ITEMSEXTEND.OPTIONS.ENDLESS_BALANCE_3, STRINGS.ITEMSEXTEND.OPTIONS.ENDLESS_BALANCE_4, STRINGS.ITEMSEXTEND.OPTIONS.ENDLESS_BALANCE_5, STRINGS.ITEMSEXTEND.OPTIONS.ENDLESS_BALANCE_6, STRINGS.ITEMSEXTEND.OPTIONS.ENDLESS_BALANCE_7, STRINGS.ITEMSEXTEND.OPTIONS.ENDLESS_BALANCE_8, STRINGS.ITEMSEXTEND.OPTIONS.ENDLESS_BALANCE_9, STRINGS.ITEMSEXTEND.OPTIONS.ENDLESS_BALANCE_10}})
	modApi:addGenerationOption("cleanup_costs", STRINGS.ITEMSEXTEND.OPTIONS.CLEANUP_COSTS, STRINGS.ITEMSEXTEND.OPTIONS.CLEANUP_COSTS_TIP,{noUpdate = true, value = 4, values = {1, 4, 7, 10}, strings={"1", "4", "7", "10"}, difficulties={{1,1},{2,4},{3,4},{4,4},{5,4},{6,4},{7,4},{8,4}}})
	modApi:addGenerationOption("enable_console_events", STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_CONSOLE_EVENTS, STRINGS.ITEMSEXTEND.OPTIONS.ENABLE_CONSOLE_EVENTS_TIP,{noUpdate = true})

	local scriptPath = modApi:getScriptPath()
	rawset(_G,"SCRIPT_PATHS",rawget(_G,"SCRIPT_PATHS") or {})
    	SCRIPT_PATHS.W93_NIAA = scriptPath
end

local function initStrings( modApi )
	local dataPath = modApi:getDataPath()
	local scriptPath = modApi:getScriptPath()

	local DLC_STRINGS = include( scriptPath .. "/strings" )
	modApi:addStrings( dataPath, "ITEMSEXTEND", DLC_STRINGS )

	util.tmerge( STRINGS.LOADING_TIPS, STRINGS.ITEMSEXTEND.LOADING_TIPS )
end

local function load( modApi, options, params, mod_options )
	local scriptPath = modApi:getScriptPath()

	if not SCRIPT_PATHS.W93_FuncLibActive or SCRIPT_PATHS.W93_FuncLibActive == false then
		log:write("Funcion Library disabled or missing! New Items and Augments is disabled.")
		return
	end

	local commondefs = include( scriptPath .. "/commondefs" )
	modApi:addTooltipDef( commondefs )

	include( scriptPath .. "/simunits" )
	include( scriptPath .. "/W93_door_controller" )
	include( scriptPath .. "/W93_lock_decoder" )
	local array = include( "modules/array" )
	local simdefs = include( "sim/simdefs" )

    	local propdefs = include( scriptPath .. "/propdefs" )
	for i,item in pairs(propdefs) do  
        	modApi:addPropDef( i, item, false )
	end

	if options["enable_augments"] and options["enable_augments"].enabled then
    		modApi:addAbilityDef( "W93_breakDoor", scriptPath .."/W93_breakDoor" )
    		modApi:addAbilityDef( "W93_console_use", scriptPath .."/W93_console_use" )
		modApi:addAbilityDef( "W93_dart_translocator", scriptPath .."/W93_dart_translocator" )
    		modApi:addAbilityDef( "W93_guard_kick", scriptPath .."/W93_guard_kick" )
    		modApi:addAbilityDef( "W93_manual_ice_break", scriptPath .."/W93_manual_ice_break" )
    		modApi:addAbilityDef( "W93_toggle_pwrbank", scriptPath .."/W93_toggle_pwrbank" )
    		modApi:addAbilityDef( "W93_toggle_shield", scriptPath .."/W93_toggle_shield" )
    		modApi:addAbilityDef( "W93_hostage_monitor", scriptPath .."/W93_hostage_monitor" )
    		modApi:addAbilityDef( "W93_useInvisiCloak", scriptPath .."/W93_useInvisiCloak" )
    		modApi:addAbilityDef( "W93_scanner_mesh", scriptPath .."/W93_scanner_mesh" )
    		modApi:addAbilityDef( "W93_wmi", scriptPath .."/W93_wmi" )

		local augmentdefs = include( scriptPath .. "/augmentdefs" )
		for name, augDef in pairs(augmentdefs) do
        	modApi:addItemDef( name, augDef )
		end
		
		if mod_manager:isInstalled( "dlc1" ) and mod_options["dlc1"] and mod_options["dlc1"].enabled then
			local augmentdefs = include( scriptPath .. "/augmentdefsDLC" )
			for name, augDef in pairs(augmentdefs) do
				modApi:addItemDef( name, augDef )
			end
		end
	end

	if options["enable_items"] and options["enable_items"].enabled then
    		modApi:addAbilityDef( "W93_alarmServer", scriptPath .."/W93_alarmServer" )
    		modApi:addAbilityDef( "W93_doorControllerPlace", scriptPath .."/W93_doorControllerPlace" )
    		modApi:addAbilityDef( "W93_doorControllerUse", scriptPath .."/W93_doorControllerUse" )
    		modApi:addAbilityDef( "W93_drone_toolkit_AP", scriptPath .."/W93_drone_toolkit_AP" )
    		modApi:addAbilityDef( "W93_drone_toolkit_firewall", scriptPath .."/W93_drone_toolkit_firewall" )
    		modApi:addAbilityDef( "W93_drone_toolkit_scanner", scriptPath .."/W93_drone_toolkit_scanner" )
		modApi:addAbilityDef( "W93_neural_data_extract", scriptPath .."/W93_neural_data_extract" )
    		modApi:addAbilityDef( "W93_paralyze", scriptPath .."/W93_paralyze" )
    		modApi:addAbilityDef( "W93_reprime", scriptPath .."/W93_reprime" )

		local itemdefs = include( scriptPath .. "/itemdefs" )
		for name, itemDef in pairs(itemdefs.item_templates) do
        	modApi:addItemDef( name, itemDef )
		end

		if mod_manager:isInstalled( "dlc1" ) and mod_options["dlc1"] and mod_options["dlc1"].enabled then
			local dlc_itemdefs = include( scriptPath .. "/itemdefsDLC" )
			for name, itemDef in pairs(dlc_itemdefs) do
        		modApi:addItemDef( name, itemDef )
			end
		end
		
		if params then
			params.W93_NoShopItemWeighting = true
		end
	end

	if options["enable_weapons"] and options["enable_weapons"].enabled then
    		modApi:addAbilityDef( "W93_switchWeaponMode", scriptPath .."/W93_switchWeaponMode" )

		local weapondefs = include( scriptPath .. "/weapondefs" )
		for name, weaponDef in pairs(weapondefs) do
        		modApi:addItemDef( name, weaponDef )
		end
		if mod_manager:isInstalled( "dlc1" ) and mod_options["dlc1"] and mod_options["dlc1"].enabled then
			local weapondefsDLC = include( scriptPath .. "/weapondefsDLC" )
			for name, weaponDef in pairs(weapondefsDLC) do
        			modApi:addItemDef( name, weaponDef )
			end
		end
	end

        local agentdefs = include("sim/unitdefs/agentdefs")
	if options["enable_rebalance"] and options["enable_rebalance"].enabled then
    		modApi:addAbilityDef( "W93_sharp_aug", scriptPath .."/W93_sharp_aug" )
    		modApi:addAbilityDef( "W93_centralaugment", scriptPath .."/W93_centralaugment" )
		local rebalancedefs = include( scriptPath .. "/rebalancedefs" )
		for name, itemDef in pairs(rebalancedefs) do
        		modApi:addItemDef( name, itemDef )
		end
		if agentdefs.sharpshooter_1_a.upgrades[3] == "item_defiblance" then
			agentdefs.sharpshooter_1_a.upgrades[3] = "W93_item_adrenaline_shalem"
		end
	else
		include( scriptPath .. "/rebalancedefs" )
		if agentdefs.sharpshooter_1_a.upgrades[3] == "W93_item_adrenaline_shalem" then
			agentdefs.sharpshooter_1_a.upgrades[3] = "item_defiblance"
		end
	end

	if options["enable_guard_loot"] and options["enable_guard_loot"].value > 0 then
		local itemdefsLoot = include( scriptPath .. "/itemdefsLoot" )
		for name, itemDef in pairs(itemdefsLoot) do
        		modApi:addItemDef( name, itemDef )
		end	
	end

	if options["enable_console_events"] and options["enable_console_events"].enabled and rawget(simdefs,"INCIDENTS") and
	options["enable_augments"] and options["enable_augments"].enabled and
	options["enable_weapons"] and options["enable_weapons"].enabled and
	options["enable_items"] and options["enable_items"].enabled then
		local incidents = include(scriptPath.."/incidents")
		for incident, weight in pairs(incidents) do
			table.insert(simdefs.INCIDENTS,{include(scriptPath.."/Incidents/"..incident),weight})
		end
	end

	if options["cleanup_costs"] then
		rawset(simdefs, "NIAA_CLEANUP", options["cleanup_costs"].value)
	end
end

local function lateLoad( modApi, options, params, mod_options )
	local scriptPath = modApi:getScriptPath()

	if not SCRIPT_PATHS.W93_FuncLibActive or SCRIPT_PATHS.W93_FuncLibActive == false then
		return
	end

	local simdefs = include( "sim/simdefs" )
	local skilldefs = include( "sim/skilldefs" )

	if options["enable_items"] and options["enable_items"].enabled then
		include( scriptPath .. "/propdefs" )
		updateProps1()
	else
		include( scriptPath .. "/propdefs" )
		restoreProps1()
	end

	if options["enable_guard_loot"] and options["enable_guard_loot"].value > 0 and
	   options["enable_items"] and options["enable_items"].enabled and
	   options["enable_weapons"] and options["enable_weapons"].enabled and
	   options["enable_augments"] and options["enable_augments"].enabled then
		include( scriptPath .. "/itemdefsLoot" )

		if options["enable_guard_loot"].value >= 2 then
			updateSafeLoot1()
		end

		if options["enable_guard_loot"].value ~= 2 then
			updateGuardLoot1()

			if mod_manager:isInstalled( "dlc1" ) and mod_options["dlc1"] and mod_options["dlc1"].enabled then
				local enabled_item = mod_options["dlc1"].options
				if enabled_item.guards and enabled_item.guards.enabled then
					updateGuardLoot2()
				end
			end

			local AGP = mod_manager:findModByName("Advanced Guard Protocol")
			if AGP and mod_options[AGP.id] and mod_options[AGP.id].enabled then
				if mod_options[AGP.id].options.ce_sysadmins and mod_options[AGP.id].options.ce_sysadmins.enabled then
					updateGuardLoot3()
				end
				if mod_options[AGP.id].options.ce_guards and mod_options[AGP.id].options.ce_guards.enabled then
					updateGuardLoot4()
				end
			end
		end
	end

	local PE = mod_manager:findModByName("Programs Extended")
	if PE and mod_options[PE.id] and mod_options[PE.id].enabled then
		if mod_options[PE.id].options.counter_ai and mod_options[PE.id].options.counter_ai.value >= 0 then
    			modApi:addAbilityDef( "W93_ai_scan", scriptPath .."/W93_ai_scan" )
    			modApi:addAbilityDef( "W93_crypto_miner", scriptPath .."/W93_crypto_miner" )
			local itemdefs = include( scriptPath .. "/itemdefs" )
			for name, itemDef in pairs(itemdefs.ai_item_templates) do
        			modApi:addItemDef( name, itemDef )
			end
		end
	end

	if options["endless_balance"] then
		if options["endless_balance"].value ~= 0 then
			for _, skill in pairs(skillNames) do
				if skilldefs.lookupSkill(skill) then
					for i=2, 5, 1 do
						if options["endless_balance"].value > 0 then
							skilldefs.lookupSkill(skill)[i].cost = (skillCostsVanilla[skill][2] * (i - 1)) * options["endless_balance"].value
						else
							skilldefs.lookupSkill(skill)[i].cost = (skillCostsVanilla[skill][2] * 2 ^ (i - 2)) * (-options["endless_balance"].value)
						end
					end
				end
			end
		elseif options["endless_balance"].value == 0 and params and params.flav_skills then
			for _, skill in pairs(skillNames) do
				if skilldefs.lookupSkill(skill) then
					for i=2, 5, 1 do
						skilldefs.lookupSkill(skill)[i].cost = skillCostsFlavorful[skill][i]
					end
				end
			end
		elseif options["endless_balance"].value == 0 then
			for _, skill in pairs(skillNames) do
				if skilldefs.lookupSkill(skill) then
					for i=2, 5, 1 do
						skilldefs.lookupSkill(skill)[i].cost = skillCostsVanilla[skill][i]
					end
				end
			end
		end
	end
end

local function lateUnload( modApi, mod_options, params )
	local scriptPath = modApi:getScriptPath()
	local array = include( "modules/array" )
        local agentdefs = include("sim/unitdefs/agentdefs")
	local simdefs = include("sim/simdefs")
	local skilldefs = include( "sim/skilldefs" )
	include( scriptPath .. "/augmentdefs" )
	include( scriptPath .. "/itemdefs" )
	include( scriptPath .. "/itemdefsLoot" )
	include( scriptPath .. "/rebalancedefs" )
	include( scriptPath .. "/weapondefs" )
	include( scriptPath .. "/propdefs" )

	restoreGuardLoot1()
	restoreProps1()

	if array.find(agentdefs.sharpshooter_1_a["upgrades"],"W93_item_adrenaline_shalem") then
		array.removeIf(agentdefs.sharpshooter_1_a["upgrades"],function(v) return v == "W93_item_adrenaline_shalem" end)
		table.insert(agentdefs.sharpshooter_1_a["upgrades"],"item_defiblance")
	end

	if mod_manager:isInstalled( "dlc1" ) and mod_options["dlc1"] and mod_options["dlc1"].enabled then
		local enabled_item = mod_options["dlc1"].options
		if enabled_item.guards and enabled_item.guards.enabled then
			restoreGuardLoot2()
		end
	end

	local AGP = mod_manager:findModByName("Advanced Guard Protocol")
	if AGP and mod_options[AGP.id] and mod_options[AGP.id].enabled then
		if mod_options[AGP.id].options.ce_sysadmins and mod_options[AGP.id].options.ce_sysadmins.enabled then
			restoreGuardLoot3()
		end
		if mod_options[AGP.id].options.ce_guards and mod_options[AGP.id].options.ce_guards.enabled then
			restoreGuardLoot4()
		end
	end

	if params and params.flav_skills then
		for _, skill in pairs(skillNames) do
			if skilldefs.lookupSkill(skill) then
				for i=2, 5, 1 do
					skilldefs.lookupSkill(skill)[i].cost = skillCostsFlavorful[skill][i]
				end
			end
		end
	else
		for _, skill in pairs(skillNames) do
			if skilldefs.lookupSkill(skill) then
				for i=2, 5, 1 do
					skilldefs.lookupSkill(skill)[i].cost = skillCostsVanilla[skill][i]
				end
			end
		end
	end
	
	rawset(simdefs, "NIAA_CLEANUP", 1)
end

return
{
	earlyInit = earlyInit,
	init = init,
	initStrings = initStrings,
	load = load,
	lateLoad = lateLoad,
	lateUnload = lateUnload,
}
