local util = include( "modules/util" )
local commondefs = include( "sim/unitdefs/commondefs" )
local simdefs = include( "sim/simdefs" )
local mainitems = include( "sim/unitdefs/itemdefs" )


local tool_templates =
{

	augment_deckard = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMS.AUGMENTS.DECKARDS,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.DECKARDS_TIP,
		flavor = STRINGS.ITEMS.AUGMENTS.DECKARDS_FLAVOR, 
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			addAbilities = "scandevice",
			addTrait = {{"W93_PWR_aug", 1}},
			installed = true,
		},		
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_head_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_head.png",	
	},

	augment_international_2 = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMS.AUGMENTS.INTERNATIONALS_2,
		desc = STRINGS.ITEMS.AUGMENTS.INTERNATIONALS_2_TIP,
		flavor = STRINGS.ITEMS.AUGMENTS.INTERNATIONALS_2_FLAVOR, 
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			cpus = 1, 
			maxcpus = 1, 
			cpuTurn = 1, 
			cpuTurnMax = 2, 
			installed = true,
			addAbilities = "alarmCPU",
			alarmCPUfinite = true,
		},		
		profile_icon = "gui/icons/skills_icons/skills_icon_small/icon-item_augment_internationale_small_alt.png",
		profile_icon_100 = "gui/icons/skills_icons/icon-item_augment_internationale_alt.png",			
	},

	augment_shalem = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMS.AUGMENTS.SHALEMS,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.SHALEMS_TIP, 
		flavor = STRINGS.ITEMS.AUGMENTS.SHALEMS_FLAVOR,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			addArmorPiercingRanged = 2,
			installed = true,
		},
		profile_icon = "gui/icons/skills_icons/skills_icon_small/icon-item_augment_shalem_small.png",
    		profile_icon_100 = "gui/icons/skills_icons/icon-item_augment_shalem.png",					
	},

	item_light_rifle_shalem = util.extend( commondefs.weapon_template )
	{
		name = STRINGS.ITEMS.RIFLE_SHALEM,
		desc = STRINGS.ITEMS.RIFLE_SHALEM_TOOLTIP,
		flavor = STRINGS.ITEMS.RIFLE_SHALEM_FLAVOR, 
		icon = "itemrigs/FloorProp_Rifle.png",		
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_gun_rifle_small.png",			
		profile_icon_100 = "gui/icons/item_icons/icon-item_gun_rifle.png",			
		equipped_icon = "gui/items/equipped_rifle.png",
        	abilities = util.tmerge( { "recharge" }, commondefs.weapon_template.abilities ),
		traits = { weaponType="rifle", baseDamage = 1, usesCharges=true, charges=1, chargesMax=1, soundRange=4 },
		sounds = {shoot="SpySociety/Weapons/Precise/shoot_rifle_silenced", reload="SpySociety/Weapons/Precise/reload_rifle", use="SpySociety/Actions/item_pickup",shell="SpySociety/Weapons/Shells/shell_rifle_wood"},
		weapon_anim = "kanim_light_rifle",
		agent_anim = "anims_2h",
		value = 600,
		notSoldAfter = 1,
	},

	item_cloakingrig_deckard = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_DECKARD,
		desc = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_DECKARD_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.CLOAK_DECKARD_FLAVOR,
		icon = "itemrigs/FloorProp_InvisiCloakTimed.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_invisicloak_small.png",			
		profile_icon_100 = "gui/icons/item_icons/icon-item_invisi_cloak.png",
		traits = { duration = 1, cooldown = 0, cooldownMax = 17, range = 3, cloakInVision = true },
		requirements = { stealth = 2 },
		abilities = { "carryable","recharge","useInvisiCloak" },
		value = 400,
		floorWeight = 1,
		notSoldAfter = 1, 
	},

	item_paralyzer_banks = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_SLOW,
		desc = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_SLOW_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.PARALYZER_SLOW_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_mindwipesyringe_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_mindwipesyringe.png",	
		abilities = { "carryable","recharge","paralyze" },
		requirements = { anarchy = 2 },
		traits = { cooldown = 0, cooldownMax = 7, koTime = 2, impare_AP = 2 },
		value = 400,
		floorWeight = 1,
		notSoldAfter = 1, 
	},

	item_shocktrap_tony = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_TONY,
		desc = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_TONY_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.SHOCK_TRAP_TONY_FLAVOR,
		icon = "itemrigs/FloorProp_AmmoClip.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_shocktrap_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_shock trap.png",		
		traits = { cooldown = 0, cooldownMax = 5, damage = 2, stun = 2, range = 3, ignoreArmor = true, friendlyFire = true, soundRange = 4, applyFn = "isClosedDoor", doorDevice = "simtrap" },
		abilities = { "doorMechanism","recharge", "carryable" },
		value = 400,
		floorWeight = 1,
	},

	item_emp_pack_tony = util.extend(commondefs.item_template)
	{
		type = "simemppack",
		name = STRINGS.ITEMSEXTEND.ITEMS.EMP_TONY,
		desc = STRINGS.ITEMSEXTEND.ITEMS.EMP_TONY_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.EMP_TONY_FLAVOR,
		icon = "itemrigs/FloorProp_emp.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_emp_small.png",
		profile_icon_100 = "gui/icons/item_icons/icon-item_emp.png",	
		abilities = { "carryable","recharge","prime_emp", },
		traits = { cooldown = 0, cooldownMax = 7, soundRange = 2, range = 2, emp_duration = 8 },
		value = 600,
		floorWeight = 2, 
	},

   	augment_nika = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMS.AUGMENTS.NIKAS,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.NIKAS_TIP, 
		flavor = STRINGS.ITEMS.AUGMENTS.NIKAS_FLAVOR,
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			installed = true,
			addTrait = {{"actionAP", {{"mpAttackRestrict", 1},{"unlimitedAttacks", true}}}, {"mpAttackRestrict", -3}, {"mpAttackRestrictMax", -3}},
			modTrait = {{"apMax", 9}},		
		},		
		profile_icon = "gui/icons/skills_icons/skills_icon_small/icon-item_augment_nika_small.png",
    		profile_icon_100 = "gui/icons/skills_icons/icon-item_augment_nika.png",		
	},

	augment_sharp_1 = util.extend(commondefs.augment_template)
	{
		name = STRINGS.ITEMS.AUGMENTS.SHARP_1,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.SHARP_1_TIP,
		flavor = STRINGS.ITEMS.AUGMENTS.SHARP_1_FLAVOR,
		traits = { 
			installed = true,
			addAbilities = "W93_sharp_aug",
		}, 
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_torso_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_torso.png",		
	},	

	augment_sharp_2 = util.extend(commondefs.augment_template)
	{
		name = STRINGS.ITEMS.AUGMENTS.SHARP_2,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.SHARP_2_TIP,
		flavor = STRINGS.ITEMS.AUGMENTS.SHARP_2_FLAVOR,
		traits = { 
			installed = true,
			addAbilities = "W93_sharp_aug",	
		}, 
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_augment_sharp_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_augment_sharp.png",		
	},

	augment_central = util.extend( commondefs.augment_template )
	{
		name = STRINGS.ITEMS.AUGMENTS.CENTRALS,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.CENTRAL_AUGMENT_TIP,
		flavor = STRINGS.ITEMS.AUGMENTS.CENTRALS_FLAVOR, 
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			ammo = 0,
			maxAmmo = 15,
			installed = true,
			finalStartItem = true,
		},
		abilities = util.tconcat( commondefs.augment_template.abilities, { "W93_centralaugment" }),		
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_head_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_head.png",	
	},

	augment_monst3r = util.extend( commondefs.augment_template )
	{
		type = "W93_augment_monst3r",
		name = STRINGS.ITEMSEXTEND.AUGMENTS.MONSTERS,
		desc = STRINGS.ITEMSEXTEND.AUGMENTS.MONSTERS_TIP,
		flavor = STRINGS.ITEMSEXTEND.AUGMENTS.MONSTERS_FLAVOR, 
		traits = util.extend( commondefs.DEFAULT_AUGMENT_TRAITS ){
			installed = true,
			modTrait = {{"mpMax", -1}},
		},		
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_head_small.png",
    		profile_icon_100 = "gui/icons/item_icons/icon-item_generic_head.png",	
	},

	W93_item_adrenaline_shalem = util.extend(commondefs.item_template)
	{
		name = STRINGS.ITEMSEXTEND.ITEMS.MED_GEL_SHALEM,
		desc = STRINGS.ITEMSEXTEND.ITEMS.MED_GEL_SHALEM_TIP,
		flavor = STRINGS.ITEMSEXTEND.ITEMS.MED_GEL_SHALEM_FLAVOR,
		icon = "itemrigs/FloorProp_Bandages.png",
		profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_medigel_small.png",	
		profile_icon_100 = "gui/icons/item_icons/icon-item_med_gel.png",	
		traits = { usesCharges=true, charges=1, chargesMax=1 },
		abilities = { "carryable","use_medgel" },
		value = 450,
		soldAfter = 10000,
	},
}

mainitems.item_prism_1.desc = STRINGS.ITEMSEXTEND.ITEMS.HOLO_MESH_TIP

return tool_templates