local simunit = include( "sim/simunit" )
local simdefs = include( "sim/simdefs" )
local simfactory = include( "sim/simfactory" )
local speechdefs = include("sim/speechdefs")

-----------------------------------------------------
-- Local functions

local W93_augment_shielding_rig = { ClassType = "W93_augment_shielding_rig" }
local W93_augment_monst3r = { ClassType = "W93_augment_monst3r" }

function W93_augment_shielding_rig:onSpawn( sim )
	sim:addTrigger( simdefs.TRG_UNIT_HIT, self )
end

function W93_augment_shielding_rig:onDespawn( sim )
	sim:removeTrigger( simdefs.TRG_UNIT_HIT, self )
end

function W93_augment_shielding_rig:onTrigger( sim, evType, evData )
	assert( evType == simdefs.TRG_UNIT_HIT )
	if evData["targetUnit"]:getTraits().neutralize_shield then
    	        local x0, y0 = evData["targetUnit"]:getLocation()

		evData["targetUnit"]:getTraits().shieldsMax = evData["targetUnit"]:getTraits().neutralize_shield
		evData["targetUnit"]:getTraits().shields = evData["targetUnit"]:getTraits().neutralize_shield
		sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = evData["targetUnit"] } )
		sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = evData["sourceUnit"] } )
		if evData["sourceUnit"]:getBrain() then
			evData["sourceUnit"]:getBrain():reset()
		end
	elseif evData["targetUnit"]:getTraits().woundsMax and evData["targetUnit"]:getTraits().woundsMax > 1 then
		sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = evData["sourceUnit"] } )
		sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = evData["targetUnit"] } )
		if evData["sourceUnit"]:getBrain() then
			evData["sourceUnit"]:getBrain():reset()
		end
	end

	local augCount, augType = evData["sourceUnit"]:countAugments("W93_augment_charged_actuators")
	if evData["melee"] and augCount > 0 and augType[1]:getTraits().ammo > 0 then
		augType[1]:getTraits().ammo = 0
	end
end

function W93_augment_monst3r:onSpawn( sim )
	sim:addTrigger( simdefs.TRG_UNIT_HIJACKED, self )
end

function W93_augment_monst3r:onDespawn( sim )
	sim:removeTrigger( simdefs.TRG_UNIT_HIJACKED, self )
end

function W93_augment_monst3r:onTrigger( sim, evType, evData )
	assert( evType == simdefs.TRG_UNIT_HIJACKED )
	if evData["sourceUnit"] == self:getUnitOwner() and not evData["unit"]:getTraits().noPWRconvert then
		local transferCpu = evData["unit"]:getTraits().cpus or 0
		local consoles = {}
		for _, consoleUnit in pairs(sim:getAllUnits()) do
			if consoleUnit:getTraits().mainframe_console and (not consoleUnit:getTraits().hijacked) and (consoleUnit:getTraits().cpus and consoleUnit:getTraits().cpus > 0) and not consoleUnit:getTraits().noPWRconvert then
				if consoleUnit ~= evData["unit"] then
					table.insert(consoles, consoleUnit)
				end
			end
		end

		if #consoles > 1 then
			local k = sim:nextRand( 1, #consoles )
			consoles[k]:getTraits().cpus = consoles[k]:getTraits().cpus + transferCpu
		elseif #consoles == 1 then
			consoles[1]:getTraits().cpus = consoles[1]:getTraits().cpus + transferCpu
		else
			local x1, y1 = evData["sourceUnit"]:getLocation()
			local CRgained = (evData["unit"]:getTraits().cpus or 0) * 50
			sim:dispatchEvent( simdefs.EV_PLAY_SOUND, "SpySociety/HUD/gameplay/gain_money")
			sim:getPC():addCredits(CRgained, sim, x1, y1)
			sim:emitSpeech( evData["sourceUnit"], speechdefs.EVENT_LOOT )
			sim._resultTable.credits_gained.econchip = sim._resultTable.credits_gained.econchip and sim._resultTable.credits_gained.econchip + CRgained or CRgained
		end
	end
end
-----------------------------------------------------
-- Interface functions


local function createItem1( unitData, sim )
	return simunit.createUnit( unitData, sim, W93_augment_shielding_rig )
end

local function createItem2( unitData, sim )
	return simunit.createUnit( unitData, sim, W93_augment_monst3r )
end

simfactory.register( createItem1 )
simfactory.register( createItem2 )

return {}